@@ -189,6 +189,18 @@ static int sinfo_utl_cube_combine_create(cpl_plugin * plugin)
     cpl_parameterlist_append(recipe->parameters, p) ;
 
 
+    p = cpl_parameter_new_value("sinfoni.sinfo_utl_cube_combine.offset_mode",
+                       CPL_TYPE_BOOL, "Offset conventions. If TRUE applies "
+                                      "reference offset correction. If FALSE: "
+                                      "take user offsets. The reference offset "
+                                      "is computed as (min_off+max_off)/2",
+                       "sinfoni.sinfo_utl_cube_combine", CPL_TRUE) ;
+    cpl_parameter_set_alias(p, CPL_PARAMETER_MODE_CLI, "offset_mode") ;
+    cpl_parameterlist_append(recipe->parameters, p) ;
+
+
+
+
     /* Return */
     return 0;
 }
