@@ -56,28 +56,11 @@
 float 
 sinfo_new_edge(float * xdat, float * parlist/*, int * npar, int * ndat */) ;
 
-float 
-sinfo_new_boltz ( float * xdat, float * parlist ) ;
 
 cpl_error_code
 sinfo_new_edge_deriv(float * xdat, 
                      float * parlist, float * dervs/*, int * npar */) ;
 
-cpl_error_code
-sinfo_new_boltz_deriv( float * xdat, float * parlist, float * dervs ) ;
-
-int sinfo_new_lsqfit ( float * xdat,
-             int   * xdim,
-             float * ydat,
-             float * wdat,
-             int   * ndat,
-             float * fpar,
-             float * epar,
-             int   * mpar,
-             int   * npar,
-             float * tol ,
-             int   * its ,
-             float * lab  ) ;
 
 int 
 sinfo_new_lsqfit_edge ( float * xdat,
@@ -101,32 +84,7 @@ sinfo_new_fit_slits_edge( cpl_image   * lineImage,
                   float        y_box,
                   float        diff_tol ) ;
 
-int 
-sinfo_new_fit_slits_boltz( cpl_image   * lineImage,
-                   FitParams ** par,
-                   float     ** sinfo_slit_pos,
-                   int          box_length,
-                   float        y_box,
-                   float        diff_tol ) ;
-
-int 
-sinfo_new_fit_slits_boltz_single_line ( cpl_image   * lineImage,
-                  float     ** sinfo_slit_pos,
-                  int          box_length,
-                  float        y_box,
-                  int          low_pos,
-                  int          high_pos ) ;
-
-int 
-sinfo_new_fit_slits_boltz_with_estimate ( cpl_image   * lineImage,
-                                float     ** sinfo_slit_pos,
-                                int          box_length,
-                                float        y_box,
-                                float        diff_tol,
-                                int          low_pos,
-                                int          high_pos ) ;
-
-int 
+int
 sinfo_new_fit_slits_edge_with_estimate ( cpl_image   * lineImage,
                                 float    ** sinfo_slit_pos,
                                 int         box_length,
@@ -135,5 +93,6 @@ sinfo_new_fit_slits_edge_with_estimate ( cpl_image   * lineImage,
                                 int         low_pos,
                                 int         high_pos ) ;
 
+
 #endif /*!SINFO_ABSOLUTE_H*/
 /**@}*/
