@@ -45,7 +45,7 @@
  ---------------------------------------------------------------------------*/
 /**
    @name    sinfo_bad_cfg_create()
-   @memo    allocate memory for a bad_cfg struct
+   @memo    allocate memory for a bad_cfg structure
    @return  pointer to allocated base bad_cfg structure
    @note    only the main (base) structure is allocated
  */
