@@ -59,8 +59,10 @@ static void parse_section_thresh(bad_config * cfg, cpl_parameterlist* cpl_cfg);
   @name     sinfo_parse_cpl_input_badnorm
   @memo     Parse input from CPL (parameters and set of input frames) 
             to create a blackboard.
-  @param    config    cpl parameter list
+  @param    cpl_cfg    cpl parameter list
   @param    sof       cpl frames list
+  @param    procatg   product category
+  @param    raw       output frameset
   @return   1 newly allocated bad_config blackboard structure.
   @doc
 
