@@ -22,27 +22,6 @@
  * $Date: 2009-04-28 11:42:18 $
  * $Revision: 1.2 $
  * $Name: not supported by cvs2svn $
- * $Log: not supported by cvs2svn $
- * Revision 1.1  2009/01/02 08:38:07  amodigli
- * added to CVS
- *
- * Revision 1.3  2007/06/06 08:17:33  amodigli
- * replace tab with 4 spaces
- *
- * Revision 1.2  2007/04/24 12:50:29  jmlarsen
- * Replaced cpl_propertylist -> uves_propertylist which is much faster
- *
- * Revision 1.1  2006/10/04 11:03:08  jmlarsen
- * Implemented QC.VRAD parameters
- *
- * Revision 1.4  2006/08/17 13:56:52  jmlarsen
- * Reduced max line length
- *
- * Revision 1.3  2006/02/28 09:15:22  jmlarsen
- * Minor update
- *
- * Revision 1.2  2005/12/19 16:17:56  jmlarsen
- * Replaced bool -> int
  *
  */
 #ifndef SINFO_BARYVEL_H
@@ -50,6 +29,9 @@
 
 #include <cpl.h>
 
+#define H_GEOLAT "ESO TEL GEOLAT"
+#define H_GEOLON "ESO TEL GEOLON"
+#define H_UTC "UTC"
 cpl_error_code
 sinfo_baryvel(const cpl_propertylist *raw_header,
          double *barycor,
