@@ -37,7 +37,8 @@
  * Local Headers
  */
 
-#include "sinfo_absolute.h"
+//#include "sinfo_absolute.h"
+#include "sinfo_boltzmann.h"
 #include "sinfo_recipes.h"
 
 /*----------------------------------------------------------------------------
@@ -1490,553 +1491,6 @@ int sinfo_new_fit_slits_boltz ( cpl_image   * lineImage,
     return 0 ;
 }
 
-/**
- * @name sinfo_new_fit_slits_boltz_single_line
-@brief fits the beginning and end position of the slitlets by using 
-       non-linear least square fitting of a Boltzmann function
-@param lineImage  emission line frame
-@param slit_pos   allocated dummy array for the slitlet positions [min32][2]
-@param box_length pixel length of the row box within the fit is done
-@param y_box:      small box in spectral direction within the slitlet 
-                   may lie.
-@param low_pos  pixel positions in spectral direction between which the line
-                       should be located.
-@param high_pos pixel positions in spectral direction between which the line
-                       should be located.
-@return      slit_pos:  beginning and end position of the slitlets to
-                                   sub-pixel accuracy
-          #               0  if it worked,
-          #              -1  if it failed,
-
-
-   @Note  fits the beginning and end position of the slitlets
-          by using non-linear least square fitting of a Boltzmann function
-          fits a Boltzmann function to the slitlet edges exposed and indicated
-          by the brightest emission lines. The slitlet is searched with
-          user given positions.
-          The least squares fit is done by using a box smaller than
-          the size of two slitlets
-TODO: NOT USED
- */
-
-int 
-sinfo_new_fit_slits_boltz_single_line ( cpl_image   * lineImage, 
-                                        float     ** slit_pos,
-                                        int          box_length,
-                                        float        y_box,
-                                        int          low_pos,
-                                        int          high_pos )
-{
-    int*     position=NULL ;
-    int   * sinfo_edge, * edgeclean ;
-    int   * dummyedge ;
-    int   * pos_row, * pos_rowclean ;
-    Vector * box_buffer ;
-    Vector * half_buffer ;
-    Vector * in_buffer ;
-
-    int   row, col ;
-    int   i, j, k, ed ;
-    int   init1 ;
-    int   nel, n_right, left_right ;
-    int   n_buf, edge_ind, shift ;
-    int   slit_length ;
-    int   margin ;
-    int   iters, xdim, ndat ;
-    int   numpar, its ;
-    int   * mpar ;
-    float * xdat, * wdat ;
-    float tol, lab ;
-    float fitpar[NPAR] ;
-    float dervpar[NPAR] ;
-    float minval, maxval ;
-    float min ;
-    float pos;
-    //float last_pos ;
-    int ilx=0;
-    //int ily=0;
-    float* pidata=NULL;
-
-    slit_length = SLITLENGTH ;
-
-    if ( NULL == lineImage )
-    {
-        sinfo_msg_error(" no line image given!" ) ;
-        return -1 ;
-    }
-
-    if ( NULL == slit_pos )
-    {
-        sinfo_msg_error(" no position array allocated!" ) ;
-        return -1 ;
-    }
-
-    if ( box_length <  4 ||
-                    box_length >  2*slit_length )
-    {
-        sinfo_msg_error(" wrong fitting box length given!" ) ;
-        return -1 ;
-    }
-
-    if ( y_box <= 0. || y_box > 6. )
-    {
-        sinfo_msg_error(" wrong y box length given!" ) ;
-        return -1 ;
-    }
-
-    ilx=cpl_image_get_size_x(lineImage);
-    //ily=cpl_image_get_size_y(lineImage);
-    pidata=cpl_image_get_data_float(lineImage);
-
-    if ( low_pos >= high_pos || low_pos < 0 || 
-                    high_pos <= 0 || high_pos >= ilx )
-    {
-        sinfo_msg_error(" wrong user given search positions!" ) ;
-        return -1 ;
-    }
-
-    /* allocate memory for the edges and the row position of the slitlets */
-    sinfo_edge         = (int*) cpl_calloc( ilx/2, sizeof(int) ) ;
-    dummyedge    = (int*) cpl_calloc( ilx/2, sizeof(int) ) ;
-    edgeclean    = (int*) cpl_calloc( ilx/2, sizeof(int) ) ;
-    pos_row      = (int*) cpl_calloc( ilx/2, sizeof(int) ) ;
-    pos_rowclean = (int*) cpl_calloc( ilx/2, sizeof(int) ) ;
-
-    /* now search for the maximum between the given positions for each col */
-    position=cpl_calloc(ilx,sizeof(int)); ;
-
-    for ( col = 0 ; col < ilx ; col++ )
-    {
-        int found_row = -1 ;
-        maxval = -FLT_MAX ;
-        for ( row = low_pos ; row <= high_pos ; row++ )
-        {
-            if ( maxval < pidata[col+row*ilx] )
-            {
-                maxval = pidata[col+row*ilx] ;
-                found_row = row ;
-            }
-        }
-        if ( maxval > -FLT_MAX && found_row > low_pos )
-        {
-            position[col] = found_row ;
-        }
-        else
-        {
-            position[col] = 0 ;
-        }
-    }
-
-    /* now find and store the raw sinfo_edge positions of the found slitlet */ 
-    ed = 0 ;
-    for ( col = 0 ; col < (ilx) - 1 ; col++ )
-    {
-        if ( position[col] > 0 && position[col+1] > 0 &&
-                        abs(position[col+1] - position[col]) > 10 )
-        {
-            sinfo_edge[ed] = col ; 
-            pos_row[ed] = position[col] ;
-            ed++ ;
-        }
-
-    }
-    if (ed <= 1)
-    {
-        sinfo_msg_error(" no slitlets found!" ) ;
-        cpl_free( sinfo_edge ) ;
-        cpl_free( pos_row ) ;
-        cpl_free( edgeclean ) ;
-        cpl_free( dummyedge ) ;
-        cpl_free( pos_rowclean ) ;
-        cpl_free( position );
-        return -1 ;
-    }
-
-    /* now find the clean sinfo_edge and row positions of the slitlets */
-    for ( i = 1 ; i <= ed ; i ++ )
-    {
-        if ( i == ed )
-        {
-            if ( (sinfo_edge[i-1] - sinfo_edge[i-2]) < 
-                            slit_length - SLIT_LEN_ERR ||
-                            (sinfo_edge[i-1] - sinfo_edge[i-2]) >
-            slit_length + SLIT_LEN_ERR )
-            {
-                dummyedge[i-1]   = -1 ;
-            }
-        }
-        if (dummyedge[i-1] != -1)
-        {
-            dummyedge[i-1] = sinfo_edge[i-1] ;
-        }
-        else
-        {
-            continue ;
-        }
-        if ( i < ed )
-        {
-            if ( (sinfo_edge[i] - sinfo_edge[i-1]) < 
-                            slit_length - SLIT_LEN_ERR ||
-                            (sinfo_edge[i] - sinfo_edge[i-1]) >
-            slit_length + SLIT_LEN_ERR )
-            {
-                dummyedge[i]   = -1 ;
-            }
-        }
-        if ( i+1 < ed && dummyedge[i] != -1 )
-        {
-            if ( (sinfo_edge[i+1] - sinfo_edge[i]) < 
-                            slit_length - SLIT_LEN_ERR ||
-                            (sinfo_edge[i+1] - sinfo_edge[i]) >
-            slit_length + SLIT_LEN_ERR )
-            {
-                dummyedge[i+1] = -1 ; 
-            }
-        }
-    }
-
-    k = 0 ;
-    for ( i = 0 ; i < ed ; i++ )
-    {
-        if ( dummyedge[i] != -1 && dummyedge[i] != 0 )
-        {
-            edgeclean[k] = dummyedge[i] ;
-            pos_rowclean[k] = pos_row[i] ;
-            k++ ;
-            if( edgeclean[k-1] > (ilx - slit_length - 2*SLIT_LEN_ERR ) )
-            {
-                pos_rowclean[k] = pos_row[ed] ;
-            }
-        }
-    }
-
-    /* determine the margins of the fitting box outside the slitlets */
-    margin = box_length / 2 ;
-
-    /* ------------------------------------------------------------------------
-     * now go through the slitlets, search along each column within a box with 
-     * half width y_box the maximum value and store these found values in a 
-     * buffer
-     */
-    for ( j = 0 ; j <= k ; j++ )
-    {
-        int m = 0 ;
-        if ( j == 0 )
-        {
-            box_buffer = sinfo_new_vector( edgeclean[0] + margin ) ;
-            for( col = 0 ; col < edgeclean[0] + margin ; col++ )
-            {
-                maxval = -FLT_MAX ;
-                for ( row = pos_rowclean[0] - sinfo_new_nint(y_box) ; 
-                                row <= pos_rowclean[0] + sinfo_new_nint(y_box) ; row++ )
-                {
-                    if ( maxval < pidata[col + ilx*row] )
-                    {
-                        maxval = pidata[col + ilx*row] ;
-                    }
-                }
-                box_buffer->data[m] = maxval ;
-                m++ ;
-            }
-        }
-        else if ( j < k )
-        {
-            box_buffer = sinfo_new_vector( edgeclean[j] - 
-                            edgeclean[j-1] + 2*margin ) ;
-            for ( col = edgeclean[j - 1] - margin ; 
-                            col < edgeclean[j] + margin ; col++ )
-            {
-                maxval = -FLT_MAX ;
-                for ( row = pos_rowclean[j] - sinfo_new_nint(y_box) ; 
-                                row <= pos_rowclean[j] + sinfo_new_nint(y_box) ; row++ )
-                {
-                    if ( maxval < pidata[col + ilx*row] )
-                    {
-                        maxval = pidata[col + ilx*row] ;
-                    }
-                }
-                box_buffer->data[m] = maxval ;
-                m++ ;
-            }
-        }
-        else 
-        {
-            box_buffer = sinfo_new_vector( ilx - edgeclean[k-1] + margin ) ;
-            for ( col = edgeclean[k - 1] - margin ; col < ilx ; col++ )
-            {
-                if ( col < 0 )
-                {
-                    col = 0 ;
-                }
-
-                maxval = -FLT_MAX ;
-                for ( row = pos_rowclean[k] - sinfo_new_nint(y_box) ; 
-                                row <= pos_rowclean[k] + sinfo_new_nint(y_box) ; row++ )
-                {
-                    if ( row < 0 )
-                    {
-                        continue ;
-                    }
-                    if ( maxval < pidata[col + row * ilx] )
-                    {
-                        maxval = pidata[col + row * ilx] ;
-                    }
-                }
-                box_buffer->data[m] = maxval ;
-                m++ ;
-            }
-        }
-
-        /* determine the minimum value in the box to get background1 
-           value for the sinfo_edge slitlets */
-        min = FLT_MAX ;
-        for ( i = 0 ; i < box_buffer->n_elements ; i++ )
-        {
-            if ( box_buffer -> data[i] < min )
-            {
-                min = box_buffer -> data[i] ;
-            }
-        }
-
-        for ( left_right = 0 ; left_right <= 1 ; left_right++ )
-        { 
-            nel = 0 ;
-            if ( left_right == 0 )
-            {
-                nel = box_buffer -> n_elements / 2 ;
-            }
-            else
-            {
-                if ( box_buffer -> n_elements % 2 == 0 )
-                {
-                    nel = box_buffer -> n_elements / 2 ;
-                }
-                else
-                {
-                    nel = box_buffer -> n_elements / 2 + 1 ;
-                }
-            }
-
-            /* now split the buffer in the midth in a left and 
-               right part for fitting */
-            half_buffer = sinfo_new_vector( nel ) ;
-            if ( left_right == 0 )
-            {
-                for ( i = 0 ; i < nel ; i++ )
-                {
-                    half_buffer -> data[i] = box_buffer -> data[i] ;
-                }
-            }
-            else
-            {
-                n_right = 0 ;
-                for ( i = box_buffer -> n_elements - 1 ; 
-                                i >= box_buffer -> n_elements - nel ; i-- )
-                {
-                    half_buffer -> data[n_right] = box_buffer -> data[i] ;
-                    n_right++ ;
-                }
-            }
-
-            xdat = (float *) cpl_calloc( nel, sizeof (float) ) ;
-            wdat = (float *) cpl_calloc( nel, sizeof (float) ) ;
-            mpar = (int *)   cpl_calloc( NPAR, sizeof (int) ) ;
-
-            /* set initial values for the fitting routine */
-            minval =  FLT_MAX ;
-            maxval = -FLT_MAX ;
-            for ( i = 0 ; i < nel ; i++ )
-            {
-                xdat[i] = i ;
-                wdat[i] = 1.0 ;
-                if ( half_buffer -> data[i] < minval )
-                {
-                    minval = half_buffer -> data[i] ;
-                }
-                if ( half_buffer -> data[i] > maxval )
-                {
-                    maxval = half_buffer -> data[i] ;
-                }
-            }
-            fitpar[0] = minval ;
-            fitpar[1] = maxval ; 
-
-            /* search for both positions of the half intensity of 
-               the hat within the buffer */
-            init1 = -1 ; 
-            for ( i = 0 ; i < nel ; i++ )
-            {
-                if ( half_buffer -> data[i] >= ( maxval + minval ) / 2. )
-                {
-                    init1 = i ;
-                    break ;
-                }
-            }
-
-            /*---------------------------------------------------------------
-             * if we have too few left background values (at the image edges)
-             * the left margin of the buffer to fit is filled with the minimal
-             * values in order to get a good fit
-             */
-
-            edge_ind = 0 ;
-            if ( init1 < 3 )
-            {
-                n_buf = half_buffer->n_elements + margin ;
-                in_buffer = sinfo_new_vector( n_buf ) ;     
-                for ( i = 0 ; i < margin ; i++ )
-                {
-                    in_buffer -> data[i] = min ;
-                }
-                shift = 0 ;
-                for ( i = margin ; i < n_buf ; i++ )
-                {
-                    in_buffer -> data[i] = half_buffer -> data[shift] ;
-                    shift++ ;
-                }
-                sinfo_new_destroy_vector ( half_buffer ) ;
-                half_buffer = sinfo_new_vector ( n_buf ) ;
-                for ( i = 0 ; i < n_buf ; i++ )
-                {
-                    half_buffer -> data[i] = in_buffer -> data[i] ;
-                }
-                edge_ind = 1 ;
-                init1 += margin ;
-                sinfo_new_destroy_vector ( in_buffer ) ;
-            }
-
-            /* determine the initial positions from the found values */
-            if ( init1 != -1 )
-            {
-                fitpar[2] = (float)init1 ;
-            }
-            fitpar[3] = 1. ;
-
-            for ( i = 0 ; i < NPAR ; i++ )
-            {
-                mpar[i] = 1 ;
-                dervpar[i] = 0. ;
-            }
-
-            xdim     = XDIMA ;
-            ndat     = nel ;
-            numpar   = NPAR ;
-            tol      = TOLA ;
-            lab      = LABA ;
-            its      = ITSA ;
-
-            /* finally, do the least squares fit over the buffer data */
-            if ( 0 > ( iters = sinfo_new_lsqfit( xdat, &xdim, 
-                            half_buffer -> data,
-                            wdat, &ndat, fitpar,
-                            dervpar, mpar, &numpar,
-                            &tol, &its, &lab )) )
-            { 
-                sinfo_msg_warning (" least squares fit failed, error "
-                                "no.: %d in slitlet: %d", iters, j) ;
-                fitpar[2] = 0. ;
-            }
-            if ( fitpar[3] <=0. )
-            { 
-                sinfo_msg_warning(" fit failed due to negative width"
-                                " of boltzmann function in slitlet: %d", j) ;
-                fitpar[2] = 0. ;
-            }
-
-            pos = fitpar[2] ;
-            if ( edge_ind == 1 )
-            {
-                pos -= (float)margin ;
-            }
-
-            /*------------------------------------------------------------- 
-             * now discern the left and the right sinfo_edge fit of the 
-             * slitlets and associate the fit results with the absolute 
-             * positions in the image consider the difference of the fitted 
-             * slit position to the expected position and decide wether the 
-             * fit is taken or the expected value is taken.
-             */
-            if ( left_right == 0 )
-            {
-                /* take care of the column position of the fit boxes to 
-                   get the absolute positions */
-                if ( j == 0 )
-                {
-                    slit_pos[0][0] = pos ;
-                    if ( slit_pos[0][0] - (int) slit_pos[0][0] == 0.)
-                    {
-                        slit_pos[0][0] = 0. ;
-                    }
-                }
-                else if ( j < k )
-                {
-                    slit_pos[j][0] = pos + (float)edgeclean[j-1] - 
-                                    (float)margin ;
-                    if ( slit_pos[j][0] - (int) slit_pos[j][0] == 0.)
-                    {
-                        slit_pos[j][0] = 0. ;
-                    }
-                }
-                else
-                {
-                    slit_pos[k][0] = pos + (float)edgeclean[k-1] - 
-                                    (float)margin ;
-                    if ( slit_pos[k][0] - (int) slit_pos[k][0] == 0.)
-                    {
-                        slit_pos[k][0] = 0. ;
-                    }
-                }
-            }
-            else
-            {
-                /* take care of the column position of the fit boxes to 
-                   get the absolute positions */
-                if ( j == 0 )
-                {
-                    slit_pos[0][1] = (float)(box_buffer->n_elements - 1) - pos;
-                    if ( slit_pos[0][1] - (int) slit_pos[0][1] == 0.)
-                    {
-                        slit_pos[0][1] = 0. ;
-                    }
-                }
-                else if ( j < k )
-                {
-                    slit_pos[j][1] = (float)(box_buffer->n_elements - 1) - pos
-                                    + (float)edgeclean[j-1] - (float)margin ;
-                    if ( slit_pos[j][1] - (int) slit_pos[j][1] == 0.)
-                    {
-                        slit_pos[j][1] = 0. ;
-                    }
-                }
-                else
-                {
-                    //last_pos = (float)(edgeclean[k-1] - 1 + slit_length) ;
-                    slit_pos[k][1] = (float)(box_buffer->n_elements - 1) - pos
-                                    + (float)edgeclean[k-1] - (float)margin ;
-                    if ( slit_pos[k][1] - (int) slit_pos[k][1] == 0.)
-                    {
-                        slit_pos[k][1] = 0. ;
-                    }
-                }
-            }
-
-            sinfo_new_destroy_vector ( half_buffer ) ;
-            cpl_free( xdat ) ;
-            cpl_free( wdat ) ;
-            cpl_free( mpar ) ;
-        }
-        sinfo_new_destroy_vector ( box_buffer ) ;
-    }
-
-    cpl_free( sinfo_edge ) ;
-    cpl_free( pos_row ) ;
-    cpl_free( edgeclean ) ;
-    cpl_free( dummyedge ) ;
-    cpl_free( pos_rowclean ) ;
-    cpl_free( position );
-    return 0 ;
-}
-
 /**
  * @name sinfo_new_fit_slits_boltz_with_estimate
 @brief its the beginning and end position of the slitlets by using 
