@@ -173,98 +173,6 @@ sinfo_distortion_smooth(cpl_image* inp,const int r,const int d)
   return NULL;
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    Restores signal considering pixels in a given range along a given
-            direction
-  @param    im image to be filtered
-  @param    rad filter radius
-  @param    d direction: 0 (X) or 1 (Y)
-  @param    k kappa value in kappa-sigma clip
-  @param    ks_method method used in kappa-sigma clip: 0 (average) 1 (median)
-  @param    n number iterations kappa-sigma clip
-  @return   smoothed image if succes, NULL else
-  TODO: not used
-*/
-
-cpl_image *
-sinfo_distortion_image_restore(const cpl_image* inp,
-                               const int r,
-                               const int d,
-                               const double kappa,
-                               const int ks_method,
-                               const int n)
-{
-
-  int sx=0;
-  int sy=0;
-  int i=0;
-  int j=0;
-  int z=0;
-  int k=0;
-
-
-  cpl_image* out=NULL;
-  const float* pi=NULL;
-  float* po=NULL;
-  int min=0;
-  cpl_vector* vec=NULL;
-  double* pv=NULL;
-  double mean=0;
-  double median=0;
-
-  cknull(inp,"Null input image!");
-  check_nomsg(sx=cpl_image_get_size_x(inp));
-  check_nomsg(sy=cpl_image_get_size_y(inp));
-  check_nomsg(out=cpl_image_duplicate(inp));
-  check_nomsg(pi=cpl_image_get_data_float_const(inp));
-  check_nomsg(po=cpl_image_get_data_float(out));
-  min = r/2;
-  check_nomsg(vec=cpl_vector_new(r));
-  check_nomsg(pv=cpl_vector_get_data(vec));
-  switch (d) {
-  case 0:
-    for(j=0;j<sy;j++) {
-      for(i=min;i<sx-min;i++) {
-    k=0;
-    for(z=i-min;z<i+min+1;z++) {
-      pv[k]=(double)pi[z+j*sx];
-          k++;
-    }
-        cknull_nomsg(vec=sinfo_vector_clip(vec,kappa,n,ks_method));
-        check_nomsg(mean=cpl_vector_get_mean(vec));
-        check_nomsg(median=cpl_vector_get_mean(vec));
-        po[i+j*sx]+=(mean-median);
-      }
-    }
-    break;
-
-  case 1:
-    for(i=0;i<sx;i++) {
-      for(j=min;j<sy-min;j++) {
-        k=0;
-    for(z=j-min;z<j+min+1;z++) {
-      pv[k]=(double)pi[i+z*sx];
-          k++;
-    }
-        cknull_nomsg(vec=sinfo_vector_clip(vec,kappa,n,ks_method));
-        check_nomsg(mean=cpl_vector_get_mean(vec));
-        check_nomsg(median=cpl_vector_get_mean(vec));
-        po[i+j*sx]+=(mean-median);
-      }
-    }
-    break;
-
-  default:
-    sinfo_msg_error("case not supported");
-    goto cleanup;
-
-  }
-  check_nomsg(cpl_image_delete((cpl_image*)inp));
-  return out;
- cleanup:
-  return NULL;
-}
 
 /*---------------------------------------------------------------------------*/
 /**
@@ -666,235 +574,6 @@ static cpl_apertures * sinfo_distortion_detect_arcs_new(
 
 
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    Estimate the distortion using vertical curved arcs
-  @param    org     the input image
-  @param    xmin
-  @param    ymin    Define the zone to take into account
-  @param    xmax
-  @param    ymax
-  @param    auto_ramp_sub   To automatically clean the image before detection
-  @param    arc_sat Saturation threshold for the arcs
-  @param    max_arc_width   Maximum arc width allowed in pixels
-  @param    degree  The degree of the fitted polynomial
-  @param    offset  The degree of the fitted polynomial
-  @param    arcs    The found arcs
-  @return   The 2d polynomial describing the distortion or NULL in error case
-
-  The arcs are expected to be vertical.
-
-  If (Xi, yi) define positions on the curved arcs, and (xi, yi) the associated
-  positions on the straight arcs, the created polynomial is Xi = P(xi, yi).
-
-  This polynomial can be used as it is by the CPL warping function to correct
-  the image.
-  TODO: not used
- */
-/*---------------------------------------------------------------------------*/
-cpl_polynomial * sinfo_distortion_estimate(
-        const cpl_image *   org,
-        int                 xmin,
-        int                 ymin,
-        int                 xmax,
-        int                 ymax,
-        int                 auto_ramp_sub,
-        int                 arc_sat,
-        int                 max_arc_width,
-        int                 degree,
-        double              offset,
-        cpl_apertures   **  arcs)
-{
-
-    cpl_image       *   local_im ;
-    cpl_image       *   label_image ;
-    double              rightmost, leftmost ;
-    cpl_bivector    **  arcs_pos ;
-    double          *   parc_posx ;
-    double          *   parc_posy ;
-    double          *   lines_pos ;
-    cpl_bivector    *   grid ;
-    double          *   pgridx ;
-    double          *   pgridy ;
-    cpl_vector      *   values_to_fit ;
-    double          *   pvalues_to_fit ;
-    int                 min_arc_range ;
-    int                 n_calib ;
-    int                 n_arcs ;
-    cpl_polynomial  *   poly2d ;
-    int                 nx ;
-    int                 i, j ;
-
-    /* AMO added to use offset */
-    cpl_vector    *     lines_pos_tmp ;
-    cpl_bivector    *   grid_tmp ;
-    int n_lines=0;
-    int k=0;
-    cpl_vector* grid_tot=0;
-    double* pgrid_tmp_x=NULL;
-    //double* pgrid_tmp_y=NULL;
-    double* pgrid_tot=NULL;
-    double* plines_pos_tmp=NULL;
-
-    /* Check entries */
-    if (org == NULL) return NULL ;
-
-    /* Initialise */
-    n_calib = ARC_NBSAMPLES ;
-    nx = cpl_image_get_size_x(org) ;
-
-    if (auto_ramp_sub) {
-        local_im = sinfo_distortion_remove_ramp(org) ;
-    } else {
-        /* Local copy of input image */
-        local_im = cpl_image_duplicate(org) ;
-    }
-    if (local_im == NULL) {
-        cpl_msg_error(cpl_func, "Cannot clean the image") ;
-        return NULL ;
-    }
-
-    /* Detect the arcs in the input image */
-    cpl_msg_info(cpl_func, "Detect arcs") ;
-    if ((*arcs = sinfo_distortion_detect_arcs(local_im,
-                    &label_image,
-                    arc_sat, max_arc_width,
-                    xmin, ymin, xmax, ymax)) == NULL) {
-        cpl_image_delete(local_im) ;
-        cpl_msg_error(cpl_func, "Cannot detect the arcs") ;
-        return NULL ;
-    }
-    n_arcs = cpl_apertures_get_size(*arcs) ;
-    cpl_msg_info(cpl_func, "%d detected arcs", n_arcs) ;
-
-    /* Check that the arcs are not concentrated in the same zone */
-    rightmost = leftmost = cpl_apertures_get_pos_x(*arcs, 1) ;
-    for (i=1 ; i<n_arcs ; i++) {
-        if (cpl_apertures_get_pos_x(*arcs, i+1) < leftmost)
-            leftmost = cpl_apertures_get_pos_x(*arcs, i+1) ;
-        if (cpl_apertures_get_pos_x(*arcs, i+1) > rightmost)
-            rightmost = cpl_apertures_get_pos_x(*arcs, i+1) ;
-    }
-    min_arc_range = (int)(nx / ARC_RANGE_FACT) ;
-    if ((int)(rightmost-leftmost) < min_arc_range) {
-        cpl_msg_error(cpl_func, "too narrow range (%g-%g)<%d",
-                rightmost, leftmost, min_arc_range) ;
-        cpl_apertures_delete(*arcs) ;
-        cpl_image_delete(local_im) ;
-        cpl_image_delete(label_image) ;
-        return NULL ;
-    }
-
-    /* Create a 2-D deformation grid with detected arcs */
-    cpl_msg_info(cpl_func, "Create deformation grid") ;
-    lines_pos = cpl_malloc(n_arcs * sizeof(double)) ;
-    if ((arcs_pos = sinfo_distortion_get_arc_positions(local_im,
-                    label_image, *arcs, n_calib, &lines_pos))==NULL){
-        cpl_msg_error(cpl_func, "cannot get arcs positions") ;
-        cpl_apertures_delete(*arcs) ;
-        cpl_image_delete(local_im) ;
-        cpl_free(lines_pos) ;
-        cpl_image_delete(label_image) ;
-        return NULL ;
-    }
-    cpl_image_delete(label_image) ;
-    cpl_image_delete(local_im) ;
-
-    /* Prepare the fitting */
-    lines_pos_tmp=cpl_vector_new(n_arcs);
-    plines_pos_tmp=cpl_vector_get_data(lines_pos_tmp);
-
-    cpl_msg_info(cpl_func, "Fit the 2d polynomial") ;
-    grid = cpl_bivector_new(n_arcs * n_calib) ;
-    pgridx = cpl_bivector_get_x_data(grid) ;
-    pgridy = cpl_bivector_get_y_data(grid) ;
-    values_to_fit = cpl_vector_new(n_arcs * n_calib) ;
-    pvalues_to_fit = cpl_vector_get_data(values_to_fit) ;
-    for (i=0 ; i<n_arcs ; i++) {
-        parc_posx = cpl_bivector_get_x_data(arcs_pos[i]) ;
-        parc_posy = cpl_bivector_get_y_data(arcs_pos[i]) ;
-        for (j=0 ; j<n_calib ; j++) {
-            plines_pos_tmp[i]=lines_pos[i] ;
-            pgridx[j+i*n_calib] = lines_pos[i] ;
-            pgridy[j+i*n_calib] = parc_posy[j] ;
-            pvalues_to_fit[j+i*n_calib] = parc_posx[j];
-
-/*
-      sinfo_msg("pgridx=%g pgridy=%g pvalues=%g",
-          pgridx[j+i*n_calib],pgridy[j+i*n_calib],pvalues_to_fit[j+i*n_calib]);
-*/
-        }
-    }
-
-
-    /* AMO new to use offset */
-    n_lines= n_arcs/32.0;
-    if(n_lines < 1) {
-      n_lines=1;
-    }
-    cpl_vector_sort(lines_pos_tmp,1);
-    plines_pos_tmp=cpl_vector_get_data(lines_pos_tmp);
-
-    grid_tmp=cpl_bivector_duplicate(grid);
-    grid_tot=cpl_vector_new(n_calib);
-    pgrid_tmp_x = cpl_bivector_get_x_data(grid_tmp) ;
-    //pgrid_tmp_y = cpl_bivector_get_y_data(grid_tmp) ;
-    pgrid_tot = cpl_vector_get_data(grid_tot);
-    for(j=0;j<n_calib;j++) {
-      pgrid_tot[j]=0;
-      for(i=n_lines ;i<n_arcs;i=i+n_lines)
-    {
-      for(k=0;k<n_lines;k++) {
-        pgrid_tot[j] += (plines_pos_tmp[i+k]-
-                             plines_pos_tmp[k]);
-        /*
-            sinfo_msg("diff=%g",(plines_pos_tmp[i+k]-
-                 plines_pos_tmp[k]));
-        */
-      }
-    }
-      /*
-      sinfo_msg("j=%d pgrid_tot=%g",j,pgrid_tot[j]);
-      */
-    }
-
-    for(j=0;j<n_calib;j++) {
-      for (i=0 ; i<n_arcs ; i++) {
-     pgridx[j+i*n_calib]=pgridx[j+i*n_calib]*
-                             ((nx/32.0)*n_lines*(31*32/2))/pgrid_tot[j]-offset;
-     /*
-         sinfo_msg_error("AMo after corr grid[%d,%d]=%g",
-                          i,k,pgridx[k+i*n_calib]);
-     */
-     pgrid_tmp_x[j+i*n_calib]=pgrid_tmp_x[j+i*n_calib]*
-                                  ((nx/32.0)*n_lines*(31*32/2))/pgrid_tot[j]-
-                                   offset;
-
-      }
-    }
-    /* end AMO: to use the offset */
-
-
-    for (i=0 ; i<n_arcs ; i++) cpl_bivector_delete(arcs_pos[i]) ;
-    cpl_free(arcs_pos) ;
-    cpl_free(lines_pos) ;
-
-    /* Apply the fitting */
-    if ((poly2d = sinfo_polynomial_fit_2d_create(grid, values_to_fit,
-                    degree, NULL))==NULL) {
-        cpl_msg_error(cpl_func, "cannot apply the 2d fit") ;
-        cpl_bivector_delete(grid) ;
-        cpl_vector_delete(values_to_fit) ;
-        cpl_apertures_delete(*arcs) ;
-        return NULL ;
-    }
-
-    /* Free and return */
-    cpl_bivector_delete(grid) ;
-    cpl_vector_delete(values_to_fit) ;
-    return poly2d ;
-}
-
 /**@}*/
 
 /*---------------------------------------------------------------------------*/
