@@ -35,18 +35,6 @@
 /*-----------------------------------------------------------------------------
                                        Prototypes
 -----------------------------------------------------------------------------*/
-cpl_polynomial * 
-sinfo_distortion_estimate(const cpl_image *, 
-                          int, 
-                          int, 
-                          int, 
-                          int, 
-                          int, 
-                          int, 
-                          int, 
-                          int, 
-                          double, 
-                          cpl_apertures **) ;
 
 cpl_polynomial * sinfo_distortion_estimate_new(
         const cpl_image *   org,
@@ -65,11 +53,5 @@ cpl_polynomial * sinfo_distortion_estimate_new(
         double              offset,
         cpl_apertures   **  arcs);
 
-cpl_image *
-sinfo_distortion_image_restore(const cpl_image* inp,
-                               const int r,
-                               const int d,
-                               const double kappa,
-                               const int ks_method,
-                               const int n);
+
 #endif
