@@ -109,7 +109,6 @@ parse_section_frames(focus_config * cfg,
 {
 
 
-   char            *       name ;
    //int nframes=0;
    int nraw=0;
    cpl_frame* frame   = NULL;
@@ -145,7 +144,7 @@ parse_section_frames(focus_config * cfg,
    /* Browse through the charmatrix to get names and file types */
    for (i=0 ; i<nraw ; i++) {
       frame = cpl_frameset_get_frame(*raw,i);
-      name= (char*) cpl_frame_get_filename(frame);
+      char* name= (char*) cpl_frame_get_filename(frame);
       if(sinfo_file_exists(name)==1) {
     /* to go on the file must exist */
     if(cpl_frame_get_tag(frame) != NULL) {
