@@ -93,13 +93,6 @@ struct amoeba_ {
   cpl_vector*   sy;
 };
 typedef struct amoeba_ amoeba_dat; 
-
-amoeba_dat* sinfo_amoeba_new(cpl_vector* vx, 
-                             cpl_vector* vy, 
-                             cpl_vector* sx, 
-                             cpl_vector* sy);
-void sinfo_amoeba_delete(amoeba_dat** a);
-
 struct qc_log_ {
   char   name[30];
   char   type[30];
@@ -108,8 +101,10 @@ struct qc_log_ {
   double n_val;
   int    n;
 };
+
 typedef struct qc_log_ qc_log; 
 
+
 struct fake_ {
   char  pro_class[FILE_NAME_SZ];
   int   frm_switch;
@@ -158,11 +153,6 @@ struct stack_ {
 
 typedef struct stack_ stack;
 
-stack* sinfo_stack_new(void);
-void sinfo_stack_delete(stack* s);
-
-
-
 struct nst_ {
   double min_dif[4];
   double fwhm[4];
