@@ -75,22 +75,6 @@
 pixelvalue 
 sinfo_kth_smallest(pixelvalue a[], int n, int k);
 
-/**
-  @name     sinfo_kth_smallest_double
-  @memo     Find the kth smallest element in a double array.
-  @param    a   Array to consider for sinfo_median search.
-  @param    n   Number of elements in the array.
-  @param    k   Rank of the element to find (between 0 and n-1).
-  @return   One element from the array.
-  @doc
- 
-  See sinfo_kth_smallest() function in the same file.
- 
-  NB: THE INPUT ARRAY IS MODIFIED.
- */
-
-double 
-sinfo_kth_smallest_double(double a[], int n, int k) ;
 
 #define median_double(a,n) \
 sinfo_kth_smallest_double(a,n,(((n)&1)?((n)/2):(((n)/2)-1)))
