@@ -98,22 +98,6 @@ sinfo_im_xy(cpl_image* im, int X, int Y)
     res = X + Y * cpl_image_get_size_x(im);
     return res;
 }
-/**
- @brief computes (x+size_x*y+size_x*size_y*z)
- @param im input image
- @param X  point X
- @param Y  point Y
- @param Z  point Z
- @return  (x+size_x*y+size_x*size_y*z)
- */
-int
-sinfo_im_xyz(cpl_image* im, int X, int Y, int Z)
-{
-    int res = 0;
-    res = X + Y * cpl_image_get_size_x(im)
-                    + Z * cpl_image_get_size_x(im) * cpl_image_get_size_y(im);
-    return res;
-}
 
 /**
  @brief computes (x+size_x*y)
@@ -131,26 +115,6 @@ sinfo_cu_xy(cpl_imagelist* cu, int X, int Y)
     res = X + Y * cpl_image_get_size_x(cpl_imagelist_get(cu, 0));
     return res;
 }
-/**
- @name sinfo_cu_xyz
- @brief computes (x+size_x*y+size_x*size_y*z)
- @param im input image
- @param X  point X
- @param Y  point Y
- @param Z  point Z
- @return  (x+size_x*y+size_x*size_y*z)
- */
-
-int
-sinfo_cu_xyz(cpl_imagelist* cu, int X, int Y, int Z)
-{
-    int res = 0;
-    res = X + Y * cpl_image_get_size_x(cpl_imagelist_get(cu, 0))
-                    + Z * cpl_image_get_size_x(cpl_imagelist_get(cu, 0))
-                                    * cpl_image_get_size_y(
-                                                    cpl_imagelist_get(cu, 0));
-    return res;
-}
 
 /**
  @name sinfo_new_c_bezier_interpolate_image(
@@ -936,142 +900,6 @@ sinfo_new_bezier(new_XYZW *p, int n, double mu, double munk, new_XYZW *res)
     return (0);
 }
 
-int
-sinfo_new_c_create_XYZ(new_Lookup *l)
-{
-    cpl_image *imX, *imY, *imZ, *imcX;
-    short i, j, k, indexI, indexJ, x, y, z;
-    int size;
-    int idlx = 0;
-    int idly = 0;
-    int idnp = 0;
-    float* piddata = NULL;
-    float* pjddata = NULL;
-    float* pXdata = NULL;
-    float* pYdata = NULL;
-    float* pZdata = NULL;
-    float* phXdata = NULL;
-
-    cpl_image* i_img = NULL;
-    cpl_image* j_img = NULL;
-
-    idlx = cpl_image_get_size_x(cpl_imagelist_get(l->id, 0));
-    idly = cpl_image_get_size_y(cpl_imagelist_get(l->id, 0));
-    idnp = cpl_imagelist_get_size(l->id);
-
-    size = idlx * idly;
-    /* allocate memory */
-    if (NULL == (imX = cpl_image_new(size, size, CPL_TYPE_FLOAT))) {
-        sinfo_msg_error(" could not allocate memory for X !\n");
-        return -1;
-    }
-    if (NULL == (imY = cpl_image_new(size, size, CPL_TYPE_FLOAT))) {
-        sinfo_msg_error(" could not allocate memory for Y !\n");
-        cpl_image_delete(imX);
-        return -1;
-    }
-    if (NULL == (imZ = cpl_image_new(size, size, CPL_TYPE_FLOAT))) {
-        sinfo_msg_error(" could not allocate memory for Z !\n");
-        cpl_image_delete(imX);
-        cpl_image_delete(imY);
-        return -1;
-    }
-    if (NULL == (imcX = cpl_image_new(size, size, CPL_TYPE_FLOAT))) {
-        sinfo_msg_error(" could not allocate memory for cX !\n");
-        cpl_image_delete(imX);
-        cpl_image_delete(imY);
-        cpl_image_delete(imZ);
-        return -1;
-    }
-
-    l->X = imX;
-    l->Y = imY;
-    l->Z = imZ;
-    l->hX = imcX;
-
-    /*Round id*/
-    for (i = 0; i < idlx; i++) {
-        for (j = 0; j < idly; j++) {
-            for (k = 0; k < idnp; k++) {
-                i_img = cpl_imagelist_get(l->id, k);
-                piddata = cpl_image_get_data_float(i_img);
-                piddata[sinfo_cu_xy(l->id, i, j)] = (float) sinfo_new_nint(
-                                piddata[sinfo_cu_xy(l->id, i, j)]);
-            }
-        }
-    }
-
-    /*Round jd*/
-    for (i = 0; i < idlx; i++) {
-        for (j = 0; j < idly; j++) {
-            for (k = 0; k < idnp; k++) {
-                j_img = cpl_imagelist_get(l->jd, k);
-                pjddata = cpl_image_get_data_float(j_img);
-                pjddata[sinfo_cu_xy(l->jd, i, j)] = (float) sinfo_new_nint(
-                                pjddata[sinfo_cu_xy(l->jd, i, j)]);
-            }
-        }
-    }
-
-    /*Fill with -1 X Y Z*/
-    for (i = 0; i < cpl_image_get_size_x(l->X); i++) {
-        for (j = 0; j < cpl_image_get_size_y(l->X); j++) {
-            pXdata = cpl_image_get_data_float(l->X);
-            pYdata = cpl_image_get_data_float(l->Y);
-            pZdata = cpl_image_get_data_float(l->Z);
-
-            pXdata[sinfo_im_xy(l->X, i, j)] = ZERO;
-            pYdata[sinfo_im_xy(l->Y, i, j)] = ZERO;
-            pZdata[sinfo_im_xy(l->Z, i, j)] = ZERO;
-        }
-    }
-#define  FORW
-#ifdef BACK
-    for( x = idlx - 1;x>=0;x--) {
-        for( y = idly - 1;y>=0;y--) {
-            for( z = idnp - 1;z>=0;z--)
-#endif
-#ifdef FORW
-    for (x = 0; x < idlx; x++) {
-        for (y = 0; y < idly; y++) {
-            for (z = 0; z < idnp; z++)
-#endif
-                            {
-                i_img = cpl_imagelist_get(l->id, z);
-                piddata = cpl_image_get_data_float(i_img);
-                j_img = cpl_imagelist_get(l->jd, z);
-                pjddata = cpl_image_get_data_float(j_img);
-                indexI = piddata[sinfo_cu_xy(l->id, x, y)];
-                indexJ = pjddata[sinfo_cu_xy(l->jd, x, y)];
-                if (indexI > 0.0 && indexI < size && indexJ > 0.0
-                                && indexJ < size) {
-                    /*sinfo_msg_debug("%d %d %d = %f, %f\n",
-                     x,y,z,(float)ICube(x,y,z),(float)JCube(x,y,z));*/
-                    pXdata = cpl_image_get_data_float(l->X);
-                    pYdata = cpl_image_get_data_float(l->Y);
-                    pZdata = cpl_image_get_data_float(l->Z);
-                    phXdata = cpl_image_get_data_float(l->hX);
-
-                    pXdata[sinfo_im_xy(l->X, indexI, indexJ)] = x;
-                    phXdata[sinfo_im_xy(l->hX, indexI, indexJ)] =
-                                    phXdata[sinfo_im_xy(l->hX, indexI, indexJ)]
-                                                    + 1;
-
-                    pYdata[sinfo_im_xy(l->Y, indexI, indexJ)] = y;
-                    /*phXdata[sinfo_im_xy(l->hX,indexI,indexJ)] =
-                     phXdata[sinfo_im_xy(l->hX,indexI,indexJ)] + 1;*/
-
-                    pZdata[sinfo_im_xy(l->Z, indexI, indexJ)] = z;
-                    /*phXdata[sinfo_im_xy(l->hX,indexI,indexJ)] =
-                     phXdata[sinfo_im_xy(l->hX,indexI,indexJ)] + 1;*/
-                }
-            }
-        }
-    }
-
-    sinfo_msg("Filled X Y Z , cX cY cZ 2D frames\n");
-    return (0);
-}
 
 /**
  @name sinfo_new_Lookup
@@ -1133,131 +961,6 @@ sinfo_new_change_mask(cpl_image * mask, cpl_image * im)
     return 0;
 }
 
-/**
- @name sinfo_new_c_bezier_find_cosmic
- @brief Find cosmic rays in an image
- @param im pointer to image
- @param mask pointer to bad pixel map
- @param look pointer to look-up table
- @param rx radius on X
- @param ry radius on Y
- @param rz radius on Z
- @param lowerI  lower I
- @param highI   higher I
- @param highJ   higher J
- @param factor  threshold factor
-
- @return if succes 0, else -1
- */
-cpl_image *
-sinfo_new_c_bezier_find_cosmic(cpl_image *im, cpl_image *mask, new_Lookup *look,
-                               short rx, short ry, short rz, short lowerI,
-                               short highI, short lowerJ, short highJ,
-                               float factor)
-{
-
-    int i, j, count;
-    cpl_imagelist * sc_im, *drs_sc_mask;
-    short szx, szy, szz;
-    float /*ant,*/newValue, old/*,dif,porcentage,distance*/;
-    double med, stdev;
-    /*cpl_image *out;*/
-    short rx_loop, ry_loop, rz_loop;
-
-    cpl_image* o_img = NULL;
-    //float* pmdata=NULL;
-    float* pidata = NULL;
-
-    int ilx = 0;
-    int ily = 0;
-
-    int mlx = 0;
-    int mly = 0;
-
-    mlx = cpl_image_get_size_x(mask);
-    mly = cpl_image_get_size_y(mask);
-    //pmdata=cpl_image_get_data_float(mask);
-
-    ilx = cpl_image_get_size_x(im);
-    ily = cpl_image_get_size_y(im);
-    pidata = cpl_image_get_data_float(im);
-
-    if (mlx != ilx || mly != ily) {
-        sinfo_msg_error(" data & mask images not compatible in size\n");
-        return NULL ;
-    }
-
-    /* allocate memory for sub cubes*/
-    szx = (rx * 2) + 1;
-    szy = (ry * 2) + 1;
-    szz = (rz * 2) + 1;
-
-    if (NULL == (sc_im = cpl_imagelist_new())) {
-        sinfo_msg_error(" could not allocate memory for data subcube\n");
-        return NULL ;
-    }
-    for (i = 0; i < szz; i++) {
-        o_img = cpl_image_new(szx, szy, CPL_TYPE_FLOAT);
-        cpl_imagelist_set(sc_im, o_img, i);
-    }
-
-    if (NULL == (drs_sc_mask = cpl_imagelist_new())) {
-        sinfo_msg_error(" could not allocate memory for mask subcube\n");
-        return NULL ;
-    }
-
-    for (i = 0; i < szz; i++) {
-        o_img = cpl_image_new(szx, szy, CPL_TYPE_FLOAT);
-        cpl_imagelist_set(drs_sc_mask, o_img, i);
-    }
-
-    count = 0;
-    for (i = 0; i < mlx; i++) {
-        for (j = 0; j < mly; j++) {
-            if (i >= lowerI && i < highI && j >= lowerJ && j < highJ) {
-
-                rx_loop = 1;
-                ry_loop = 1;
-                rz_loop = 1;
-                newValue = sinfo_new_c_bezier_correct_cosmic(i, j, im, mask,
-                                sc_im, drs_sc_mask, look, rx_loop, ry_loop,
-                                rz_loop, &med, &stdev, factor);
-                /* if no valid neighboors are found, increase size of
-                 sub cube until max radius is reached */
-                while (newValue == cubeNONEIGHBOR && rx_loop < rx
-                                && ry_loop < ry && rz_loop < rz) {
-                    rx_loop++;
-                    ry_loop++;
-                    rz_loop++;
-                    /*sinfo_msg_debug("Increasing radius to %d, in %d %d",
-                     rx_loop, i, j) ;  */
-                    newValue = sinfo_new_c_bezier_correct_cosmic(i, j, im, mask,
-                                    sc_im, drs_sc_mask, look, rx_loop, ry_loop,
-                                    rz_loop, &med, &stdev, factor);
-                }
-                /*give up on increasing the size*/
-                if (isnan(newValue) || newValue == cubeNONEIGHBOR)
-                    /*<= -3.e10 ZERO )*/
-                    continue;
-
-                old = pidata[sinfo_im_xy(im, i, j)];
-                if (newValue != old) {
-                    pidata[sinfo_im_xy(im, i, j)] = newValue;
-                    /*sinfo_msg_debug("[%d,%d]=%f -> %f, med= %f, stdev=%f",
-                     i,j, old, newValue, med, stdev ); */
-                    count++;
-                }
-            }
-        }
-    }
-
-    sinfo_msg_debug("bad pixels count: %d", count);
-
-    cpl_imagelist_delete(sc_im);
-    cpl_imagelist_delete(drs_sc_mask);
-    return im;
-}
-
 /**
  @name sinfo_new_c_bezier_correct_cosmic
  @brief Correct cosmic rays in an image
