@@ -77,9 +77,7 @@ typedef struct new_lookup_ {
 
 
 int sinfo_im_xy(cpl_image* im, int X, int Y); 
-int sinfo_im_xyz(cpl_image* im, int X, int Y, int Z); 
 int sinfo_cu_xy(cpl_imagelist* cu, int X, int Y); 
-int sinfo_cu_xyz(cpl_imagelist* cu, int X, int Y, int Z); 
 
 /*----------------------------------------------------------------------------
  *                        Function ANSI C prototypes
@@ -156,22 +154,6 @@ sinfo_new_c_bezier_correct_cosmic( int ipos ,
                                        float factor );
 
 
-cpl_image * 
-sinfo_new_c_bezier_find_cosmic(cpl_image *im, 
-                                    cpl_image *mask, 
-                                    new_Lookup *look, 
-                                    short rx, 
-                                    short ry, 
-                                    short rz,
-                                    short lowerI, 
-                                    short highI, 
-                                    short lowerJ, 
-                                    short highJ, 
-                                    float factor );
-
-
-int sinfo_new_c_create_XYZ( new_Lookup *l );
-
 new_Lookup * sinfo_new_lookup( void ) ;
 
 void sinfo_new_destroy_lookup( new_Lookup *l ) ;
