@@ -39,7 +39,8 @@
 #include "sinfo_finddist_ini_by_cpl.h"
 #include "sinfo_wave_calibration.h"
 #include "sinfo_cube_construct.h"
-#include "sinfo_absolute.h"
+//#include "sinfo_absolute.h"
+#include "sinfo_boltzmann.h"
 #include "sinfo_distortion.h"
 #include "sinfo_utilities.h"
 #include "sinfo_recipes.h"
