@@ -841,7 +841,6 @@ new_lamp_flats_det_ncounts(cpl_frameset* raw, flat_config* cfg)
 
     char filename[MAX_NAME_SIZE];
 
-    cpl_frame* frm=NULL;
     cpl_frame* frm_dup=NULL;
     cpl_frame* on_frm=NULL;
     cpl_frame* of_frm=NULL;
@@ -858,7 +857,7 @@ new_lamp_flats_det_ncounts(cpl_frameset* raw, flat_config* cfg)
     nraw = cpl_frameset_get_size(raw);
 
     for (i=0; i< nraw; i++) {
-        frm = cpl_frameset_get_frame(raw,i);
+        cpl_frame* frm = cpl_frameset_get_frame(raw,i);
         frm_dup = cpl_frame_duplicate(frm);
         if(sinfo_frame_is_on(frm) == 1) {
             cpl_frameset_insert(on_set,frm_dup);
@@ -902,7 +901,7 @@ new_lamp_flats_det_ncounts(cpl_frameset* raw, flat_config* cfg)
                     of_frm=cpl_frame_duplicate(tmp_of_frm);
                 }
             }
-            strcpy(filename,cpl_frame_get_filename(of_frm));
+            //strcpy(filename,cpl_frame_get_filename(of_frm));
             frm_dup=cpl_frame_duplicate(of_frm);
             cpl_frameset_insert(wrk_set,frm_dup);
             strcpy(filename,cpl_frame_get_filename(of_frm));
@@ -925,7 +924,6 @@ new_qc_get_cnt(cpl_frameset* on_set, cpl_frameset* of_set, flat_config* cfg)
 {
 
     int i=0;
-    int nsat=0;
     int non=0;
     int nof=0;
     int nfr=0;
@@ -935,15 +933,8 @@ new_qc_get_cnt(cpl_frameset* on_set, cpl_frameset* of_set, flat_config* cfg)
     cpl_vector* vec_of=NULL;
     cpl_vector* vec_di=NULL;
     cpl_vector* vec_nsat=NULL;
-    cpl_frame* on_frm=NULL;
-    cpl_frame* of_frm=NULL;
 
-    cpl_image* dif_ima=NULL;
-    cpl_image* on_ima=NULL;
-    cpl_image* of_ima=NULL;
-    cpl_image* tmp_ima=NULL;
 
-    double med=0;
     non = cpl_frameset_get_size(on_set);
     nof = cpl_frameset_get_size(of_set);
     nfr = (non <= nof) ? non : nof;
@@ -954,25 +945,25 @@ new_qc_get_cnt(cpl_frameset* on_set, cpl_frameset* of_set, flat_config* cfg)
 
 
     for (i=0; i< nfr; i++) {
-        on_frm = cpl_frameset_get_frame(on_set,i);
+        cpl_frame* on_frm = cpl_frameset_get_frame(on_set,i);
         strcpy(name,cpl_frame_get_filename(on_frm));
-        on_ima = cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
-        med= cpl_image_get_median(on_ima);
+        cpl_image* on_ima = cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
+        double med= cpl_image_get_median(on_ima);
         cpl_vector_set(vec_on,i,med);
 
-        tmp_ima = cpl_image_duplicate(on_ima);
+        cpl_image* tmp_ima = cpl_image_duplicate(on_ima);
         cpl_image_threshold(tmp_ima,SINFO_DBL_MIN,
                             cfg->qc_thresh_max,0,1);
-        nsat=cpl_image_get_flux(tmp_ima);
+        int nsat=cpl_image_get_flux(tmp_ima);
         cpl_vector_set(vec_nsat,i,nsat);
 
         /* Are you sure to have same frames off as on ? */
-        of_frm = cpl_frameset_get_frame(of_set,i);
+        cpl_frame* of_frm = cpl_frameset_get_frame(of_set,i);
         strcpy(name,cpl_frame_get_filename(of_frm));
-        of_ima = cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
+        cpl_image* of_ima = cpl_image_load(name,CPL_TYPE_FLOAT,0,0);
         med= cpl_image_get_median(of_ima);
         cpl_vector_set(vec_of,i,med);
-        dif_ima = cpl_image_subtract_create(on_ima,of_ima);
+        cpl_image* dif_ima = cpl_image_subtract_create(on_ima,of_ima);
         med= cpl_image_get_median(dif_ima);
         cpl_vector_set(vec_di,i,med);
 
