@@ -226,7 +226,7 @@ int sinfo_new_objnod (const char* plugin_id,cpl_parameterlist* config,
         }
     }
 
-    ck0(sinfo_auto_size_cube5(cfg,&ref_offx,&ref_offy,
+    ck0(sinfo_auto_size_cube_new(cfg,&ref_offx,&ref_offy,
                                 &offx_min,&offy_min,
                                 &offx_max,&offy_max),
                              "Error resizing cube");
@@ -289,9 +289,10 @@ int sinfo_new_objnod (const char* plugin_id,cpl_parameterlist* config,
           goto cleanup;
         }
       times[n] = exptime ;
-          ck0(sinfo_new_assign_offset(n,name,offsetx,offsety,
+          ck0(sinfo_assign_offset_from_fits_header(n,name,offsetx,offsety,
                                       ref_offx,ref_offy),
                                       "Error assigning offsets");
+          //sinfo_msg("assigned offset: %g %g",offsetx[n],offsety[n]);
 
     }
 
