@@ -56,7 +56,7 @@
 #include "sinfo_error.h"
 #include "sinfo_utils_wrappers.h"
 #include "sinfo_globals.h"
-//Used only for sinfo_propertylist_has
+//Used only for cpl_propertylist_has
 #include "sinfo_dfs.h"
 /*----------------------------------------------------------------------------
                                 Defines
@@ -559,7 +559,7 @@ sinfo_add_com_psf_qclog(const char* fname,cpl_table** qclog_tbl)
     cknull(plist = cpl_propertylist_load(fname, 0),
            "getting header from reference ima frame %s",fname);
 
-    if (sinfo_propertylist_has(plist, KEY_NAME_LOOP_STATE)) {
+    if (cpl_propertylist_has(plist, KEY_NAME_LOOP_STATE)) {
         sinfo_qclog_add_string(*qclog_tbl,KEY_NAME_LOOP_STATE,
                         cpl_propertylist_get_string(plist,KEY_NAME_LOOP_STATE),
                         KEY_HELP_LOOP_STATE,"%s");
@@ -567,14 +567,14 @@ sinfo_add_com_psf_qclog(const char* fname,cpl_table** qclog_tbl)
 
 
 
-    if (sinfo_propertylist_has(plist, KEY_NAME_LOOP_LGS)) {
+    if (cpl_propertylist_has(plist, KEY_NAME_LOOP_LGS)) {
         sinfo_qclog_add_int(*qclog_tbl,KEY_NAME_LOOP_LGS,
                         cpl_propertylist_get_int(plist,KEY_NAME_LOOP_LGS),
                         KEY_HELP_LOOP_LGS,"%d");
     }
 
 
-    if (sinfo_propertylist_has(plist, KEY_NAME_INS1_MODE)) {
+    if (cpl_propertylist_has(plist, KEY_NAME_INS1_MODE)) {
         sinfo_qclog_add_string(*qclog_tbl,KEY_NAME_INS1_MODE,
                         cpl_propertylist_get_string(plist,KEY_NAME_INS1_MODE),
                         KEY_HELP_INS1_MODE,"%s");
@@ -608,8 +608,6 @@ sinfo_get_strehl_from_image(cpl_image* img,
 
     cpl_image* img_dup=NULL;
 
-    double dlam=0.;
-    double lam=0.;
     /*
   double max_ima_cx=0.;
   double max_ima_cy=0.;
@@ -631,8 +629,8 @@ sinfo_get_strehl_from_image(cpl_image* img,
     int ima_szy=0;
 
 
-    lam = (double)0.5*(ws+we);
-    dlam=we-ws;
+    double lam = (double)0.5*(ws+we);
+    double dlam=we-ws;
     sinfo_msg_debug("ws=%f we=%f dl=%f",ws,we,dlam);
     check_nomsg(img_dup=cpl_image_duplicate(img));
     sinfo_clean_nan(&img_dup);
@@ -716,8 +714,8 @@ sinfo_get_strehl_from_slice(cpl_imagelist* cube,
     cpl_image* img_dup=NULL;
     cpl_image* img=NULL;
 
-    double dlam=0.;
-    double lam=0.;
+
+
     /*
   double max_ima_cx=0.;
   double max_ima_cy=0.;
@@ -739,8 +737,8 @@ sinfo_get_strehl_from_slice(cpl_imagelist* cube,
     int ima_szy=0;
 
 
-    lam = (double)0.5*(ws+we);
-    dlam=we-ws;
+    double lam = (double)0.5*(ws+we);
+    double dlam=we-ws;
 
 
     img=sinfo_new_average_cube_to_image_between_waves(cube,disp,cWave,ws,we);
@@ -1029,8 +1027,6 @@ static cpl_table* sinfo_get_strehl_from_cube(cpl_imagelist* cube,
 {
     cpl_table* strehl_tbl=NULL;
 
-    double dispersion=0.;
-    double centralWave=0.;
     /* double wrange=0; */
     double wstart=0;
     double wstep=0;
@@ -1066,8 +1062,8 @@ static cpl_table* sinfo_get_strehl_from_cube(cpl_imagelist* cube,
     strehl_bg_r2=SINFO_BKG_R2*pscale;
 
     plist=cpl_propertylist_load(name,0);
-    dispersion=sinfo_pfits_get_cdelt3(plist);
-    centralWave=sinfo_pfits_get_crval3(plist);
+    double dispersion=sinfo_pfits_get_cdelt3(plist);
+    double centralWave=sinfo_pfits_get_crval3(plist);
     /* naxis3=sinfo_pfits_get_naxis3(plist); */
     sinfo_free_propertylist(&plist);
     /* wrange=dispersion*naxis3; */
@@ -1180,10 +1176,7 @@ sinfo_get_frm12(cpl_frameset* sof,cpl_frame** frm1,cpl_frame** frm2){
 
     cpl_frameset* obs=NULL;
     int nobs=0;
-    float eps=0.0001;
     float* pix_scale=NULL;
-    int i=0;
-    cpl_frame* frame=NULL;
 
     obs = cpl_frameset_new();
     sinfo_contains_frames_kind(sof,obs,PRO_OBS_PSF);
@@ -1207,8 +1200,9 @@ sinfo_get_frm12(cpl_frameset* sof,cpl_frame** frm1,cpl_frame** frm2){
         return -1;
     } else {
         pix_scale=cpl_calloc(nobs,sizeof(float));
-        for(i=0;i<nobs;i++) {
-            frame=cpl_frameset_get_frame(obs,i);
+        float eps=0.0001;
+        for(int i=0;i<nobs;i++) {
+            cpl_frame* frame=cpl_frameset_get_frame(obs,i);
             pix_scale[i]=sinfo_pfits_get_pixelscale(
                             (char*)cpl_frame_get_filename(frame));
             if(fabs(pix_scale[i]-0.025)< eps) {
@@ -1217,6 +1211,7 @@ sinfo_get_frm12(cpl_frameset* sof,cpl_frame** frm1,cpl_frame** frm2){
                 *frm2=cpl_frame_duplicate(frame);
             } else {
                 sinfo_msg_error("No proper frame found for strehl computation");
+                cpl_free(pix_scale);
                 return -1;
             }
         }
@@ -1818,10 +1813,10 @@ sinfo_get_star_features(const cpl_image* im,
 
     sinfo_msg_debug("star_radius=%d",radius);
     //We find the image centroid
+
     if(NULL != (iqe=cpl_image_iqe(im,sx/2-radius,sy/2-radius,
                     sx/2+radius,sy/2+radius))) {
 
-
         piqe=cpl_bivector_get_x_data(iqe);
         //*star_peak=piqe[5];
         xm=piqe[0];
@@ -1832,6 +1827,7 @@ sinfo_get_star_features(const cpl_image* im,
         sinfo_msg_debug("Find min of: %g %g %g %g",xm,sx-xm,ym,sy-ym);
         ixm=floor(xm);
         iym=floor(ym);
+
         sinfo_msg_debug("ixm=%d iym=%d",ixm,iym);
         dim_new=floor(sinfo_find_min_of_four(xm,sx-xm,ym,sy-ym));
         sinfo_msg_debug("dim_new=%d",dim_new);
@@ -1845,31 +1841,42 @@ sinfo_get_star_features(const cpl_image* im,
         //compute the background of this last image
         check_nomsg(sinfo_get_bkg_4corners(im_new,bkg_sx,bkg_sy,bkg,&bkg_stdev));
 
-
-
         sinfo_free_bivector(&iqe);
-
         //Determine the image pick on the new coordinate system
-        iqe=cpl_image_iqe(im_new,dim_new-radius,dim_new-radius,
-                        dim_new+radius,dim_new+radius);
-        piqe=cpl_bivector_get_x_data(iqe);
-        sinfo_msg_debug("xc=%g yc=%g",piqe[0],piqe[1]);
-        *xc=piqe[0]-dim_new-1;
-        *yc=piqe[1]-dim_new-1;
+        if(NULL != (iqe=cpl_image_iqe(im_new,dim_new-radius,dim_new-radius,
+                        dim_new+radius,dim_new+radius))) {
 
+            piqe=cpl_bivector_get_x_data(iqe);
+            sinfo_msg_debug("xc=%g yc=%g",piqe[0],piqe[1]);
+            *xc=piqe[0]-dim_new-1;
+            *yc=piqe[1]-dim_new-1;
 
-        sinfo_msg_debug("xc=%g yc=%g",*xc,*yc);
-        //*peak=piqe[5];
-        *peak=cpl_image_get_max_window(im_new,dim_new-radius,dim_new-radius,
-                        dim_new+radius,dim_new+radius);
+            sinfo_msg_debug("xc=%g yc=%g",*xc,*yc);
+            //*peak=piqe[5];
+            *peak=cpl_image_get_max_window(im_new,dim_new-radius,dim_new-radius,
+                            dim_new+radius,dim_new+radius);
 
-        sinfo_get_flux_above_bkg(im_new,kappa,bkg_stdev,flux);
-        *peak -= (*bkg);
-        sinfo_msg_debug("star peak=%g bkg=%g",*peak,*bkg);
+            sinfo_get_flux_above_bkg(im_new,kappa,bkg_stdev,flux);
+            *peak -= (*bkg);
+            sinfo_msg_debug("star peak=%g bkg=%g",*peak,*bkg);
+            sinfo_free_bivector(&iqe);
 
+        } else {
 
-        sinfo_free_bivector(&iqe);
+            sinfo_msg_warning("IQE fit failed");
+            cpl_error_reset();
+            sinfo_msg_debug("xc=%d yc=%d radius=%d",xpos,ypos,radius);
+            *xc=xpos-sx/2;
+            *yc=ypos-sy/2;
+            sinfo_msg_debug("xc=%g yc=%g",*xc,*yc);
+            check_nomsg(sinfo_get_bkg_4corners(im,bkg_sx,bkg_sy,bkg,&bkg_stdev));
+            check_nomsg(sinfo_get_safe_box(&llx, &lly, &urx, &ury, xpos,ypos,radius,
+                            64,64));
+            check_nomsg(*peak=cpl_image_get_max_window(im,llx,lly,urx,ury)-(*bkg));
+            sinfo_get_flux_above_bkg(im,kappa,bkg_stdev,flux);
+            sinfo_msg_debug("star peak=%g bkg=%g",*peak,*bkg);
 
+        }
 
     } else {
         sinfo_msg_warning("IQE fit failed");
@@ -1884,19 +1891,12 @@ sinfo_get_star_features(const cpl_image* im,
         check_nomsg(*peak=cpl_image_get_max_window(im,llx,lly,urx,ury)-(*bkg));
         sinfo_get_flux_above_bkg(im,kappa,bkg_stdev,flux);
         sinfo_msg_debug("star peak=%g bkg=%g",*peak,*bkg);
-
-
     }
 
-
-
     cleanup:
     sinfo_free_image(&im_new);
     sinfo_free_bivector(&iqe);
 
-
-
-
     if (cpl_error_get_code() != CPL_ERROR_NONE) {
         return cpl_error_get_code();
     } else {
@@ -2149,7 +2149,7 @@ sinfo_get_bkg_4corners(const cpl_image *img,
     check_nomsg(sy=cpl_image_get_size_y(img));
 
     check_nomsg(img_bkg=cpl_image_new(2*bkg_sx,2*bkg_sy,CPL_TYPE_FLOAT));
-    cpl_image* img_ext;
+    cpl_image* img_ext=NULL;
     img_ext=cpl_image_extract(img,1,1,bkg_sx,bkg_sy);
     check_nomsg(cpl_image_copy(img_bkg,img_ext,1,1));
     sinfo_free_image(&img_ext);
@@ -2173,6 +2173,7 @@ sinfo_get_bkg_4corners(const cpl_image *img,
 
 
     cleanup:
+	sinfo_free_image(&img_ext);
     sinfo_free_image(&img_bkg);
 
     if (cpl_error_get_code() != CPL_ERROR_NONE) {
