@@ -511,42 +511,5 @@ static void new_reverse_tanh_kernel(double * data, int nn)
 }
 #undef KERNEL_SW
 
-
-
-/*-------------------------------------------------------------------------*/
-/**
-  @name        sinfo_new_show_interpolation_kernel
-  @memo        Print out an interpolation kernel values on stdout.
-  @param    kernel_name        Name of the kernel to print out.
-  @return    void
-  @doc
-
-  Takes in input a kernel name, generates the corresponding kernel and
-  prints it out on stdout, then discards the generated kernel.
-
-  For debugging purposes mostly.
- */
-/*--------------------------------------------------------------------------*/
-
-void sinfo_new_show_interpolation_kernel(char * kernel_name)
-{
-    double    *    ker ;
-    int            i ;
-    double        x ;
-
-
-    ker = sinfo_new_generate_interpolation_kernel(kernel_name) ;
-    if (ker == NULL)
-        return ;
-
-    (void)fprintf(stdout, "# Kernel is %s\n", kernel_name) ;
-    x = 0.00 ;
-    for (i=0 ; i<KERNEL_SAMPLES ; i++) {
-        (void)fprintf(stdout, "%g %g\n", x, ker[i]) ;
-        x += 1.00 / (double)TABSPERPIX ;
-    }
-    cpl_free(ker) ;
-    return ;
-}
 /**@}*/
 
