@@ -187,23 +187,4 @@ sinfo_new_warp_image_generic(
 
 double * sinfo_new_generate_tanh_kernel(double steep) ;
 
-
-/*-------------------------------------------------------------------------*/
-/**
-  @name     sinfo_new_show_interpolation_kernel
-  @memo     Print out an interpolation kernel values on stdout.
-  @param    kernel_name     Name of the kernel to print out.
-  @return   void
-  @doc
- 
-  Takes in input a kernel name, generates the corresponding kernel and
-  prints it out on stdout, then discards the generated kernel.
- 
-  For debugging purposes mostly.
- */
-/*--------------------------------------------------------------------------*/ 
-
-void sinfo_new_show_interpolation_kernel(char * kernel_name) ;
-
-
 #endif
