@@ -527,7 +527,7 @@ sinfo_new_stdstar(const char* plugin_id,
      * in the image are flagged. Better would be to flag any bad pixel/outlier
      * using HDRL.
      */
-    int margin=3;
+    //int margin=3;
     cpl_image_reject_value(std_med_dup,CPL_VALUE_NAN);
 
     double peak=0;
