@@ -126,7 +126,6 @@ parse_section_frames(object_config * cfg,
    int nstk=0;
    cpl_size             *   labels=NULL ;
    cpl_size                 nlabels=0 ;
-   cpl_frameset    *   cur_set=NULL ;
    cpl_frame       *   cur_frame=NULL ;
    char * tag=NULL;
    int i=0;
@@ -161,7 +160,7 @@ parse_section_frames(object_config * cfg,
    } else {
      /* For each label */
      for (i=0 ; i<nlabels ; i++) {
-       cur_set = cpl_frameset_extract(sof, labels, i) ;
+       cpl_frameset* cur_set = cpl_frameset_extract(sof, labels, i) ;
        cur_frame = cpl_frameset_get_frame(cur_set, 0) ;
        tag = (char*)cpl_frame_get_tag(cur_frame) ;
        if (sinfo_is_stack(tag) == 1) {
