@@ -96,80 +96,6 @@ static char * sinfo_strcrop(char * s)
     return l ;
 }
 
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    Query a PAF file for a value.
-  @param    filename    Name of the PAF to query.
-  @param    key            Name of the key to query.
-  @return    1 pointer to statically allocated string, or NULL.
-
-  This function parses a PAF file and returns the value associated to a
-  given key, as a pointer to an internal statically allocated string.
-  Do not try to free or modify the contents of the returned string!
-
-  If the key is not found, this function returns NULL.
- */
-/*---------------------------------------------------------------------------*/
-char * sinfo_paf_query(
-                char    *   filename,
-                char    *   key)
-{
-    static char value[ASCIILINESZ];
-    FILE    *    paf ;
-    char        line[ASCIILINESZ+1];
-    char        val[ASCIILINESZ+1];
-    char        head[ASCIILINESZ+1];
-    int            found ;
-    int            len ;
-
-    /* Check inputs */
-    if (filename==NULL || key==NULL) return NULL ;
-
-    /* Check PAF validity */
-    if (sinfo_is_paf_file(filename)!=1) {
-        sinfo_msg_error("not a PAF file: [%s]", filename);
-        return NULL ;
-    }
-
-    /* Open file and read it */
-    paf = fopen(filename, "r");
-    if (paf==NULL) {
-        sinfo_msg_error("opening [%s]", filename);
-        return NULL ;
-    }
-
-    found = 0 ;
-    while (fgets(line, ASCIILINESZ, paf)!=NULL) {
-        sscanf(line, "%[^ ]", head);
-        if (!strcmp(head, key)) {
-            /* Get value */
-            sscanf(line, "%*[^ ] %[^;]", value);
-            found ++ ;
-            break ;
-        }
-    }
-    if (!found) {
-        fclose(paf);
-        return NULL ;
-    }
-
-    /* Remove trailing blanks */
-    strcpy(val, sinfo_strcrop(value));
-    /* Get rid of possible quotes */
-    len = strlen(val);
-    if (val[0]=='\"' && val[len-1]=='\"') {
-        strncpy(value, val+1, len-2);
-        value[len-2]=(char)0;
-    } else {
-        strcpy(value, val);
-    }
-    if(paf!=NULL){
-        fclose(paf);
-    }
-    return value ;
-}
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    returns 1 if file is in PAF format, 0 else
@@ -352,37 +278,6 @@ double sinfo_pfits_get_targ_delta(const cpl_propertylist * plist)
     return cpl_propertylist_get_double(plist,"ESO INS TARG DELTA");
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the arcfile   
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_arcfile(const cpl_propertylist * plist)
-{
-    return (const char*) cpl_propertylist_get_string(plist,KEY_NAME_ARCFILE);
-}
-
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the instrument setup id
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_ins_setup(const cpl_propertylist * plist)
-{
-    if(cpl_propertylist_get_string(plist,"ESO INS SETUP ID")) {
-        return (const char*) cpl_propertylist_get_string(plist,"ESO INS SETUP ID");
-    } else {
-        cpl_error_reset();
-        return "Dark";
-    }
-
-}
-
 
 /*---------------------------------------------------------------------------*/
 /**
@@ -410,19 +305,6 @@ double sinfo_pfits_get_posangle(const cpl_propertylist * plist)
     return cpl_propertylist_get_double(plist,"ESO ADA POSANG");
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the value of the CUMOFFSETX keyword in a header
-  @param    plist   FITS header
-  @return   keyword value
- */
-/*---------------------------------------------------------------------------*/
-double sinfo_pfits_get_DEC(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_double(plist,"DEC");
-}
-
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the value of the CUMOFFSETX keyword in a header
@@ -447,19 +329,6 @@ double sinfo_pfits_get_cumoffsety(const cpl_propertylist * plist)
     return cpl_propertylist_get_double(plist,"ESO SEQ CUMOFFSETY");
 }
 
-/*---------------------------------------------------------------------------*/
-/**     
-  @brief    find out the date of observation  
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */ 
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_date_obs(const cpl_propertylist * plist)
-{
-
-    return (const char*) cpl_propertylist_get_string(plist,"DATE-OBS");
-
-}
 
 /*---------------------------------------------------------------------------*/
 /** 
@@ -504,43 +373,6 @@ float sinfo_pfits_get_pixelscale(const char * name)
     return pixscale;
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the character string associated to the FILT1.NAME keyword
-            in an sinfoni header
-  @param    plist    FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_band(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_string(plist,"ESO INS FILT1 NAME");
-}
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the filter in imaging 
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_filter_im(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_string(plist,"ESO INS FILT1 NAME");
-}
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the character string associated to the instrument
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-const char * sinfo_pfits_get_instrument(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_string(plist,"INSTRUME");
-}
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the mjd-obs keyword 
@@ -553,19 +385,6 @@ double sinfo_pfits_get_mjdobs(const cpl_propertylist * plist)
     return cpl_propertylist_get_double(plist,"MJD-OBS");
 }
 
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the character string associated to INS.MONOC1.POS
-  @param    plist   FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-double sinfo_pfits_get_monoc_pos(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_double(plist,"INS MONOC1 POS");
-}
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the character string associated to the NDIT keyword
@@ -616,23 +435,6 @@ int sinfo_pfits_get_naxis3(const cpl_propertylist * plist)
     return cpl_propertylist_get_int(plist,"NAXIS3");
 }
 
-
-
-
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the character string associated to the CRPIX1 keyword
-  @param    plist    FITS header
-  @return   keyword value
- */
-/*---------------------------------------------------------------------------*/
-double sinfo_pfits_get_crpix1(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_double(plist,"CRPIX1");
-}
-
-
-
 /*---------------------------------------------------------------------------*/
 /**
   @brief    find out the character string associated to the CRPIX2 keyword
@@ -751,18 +553,6 @@ double sinfo_pfits_get_ra(const cpl_propertylist * plist)
     return cpl_propertylist_get_double(plist,"RA");
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-  @brief    find out the spectral resolution
-  @param    plist    FITS header
-  @return   pointer to statically allocated character string
- */
-/*---------------------------------------------------------------------------*/
-double sinfo_pfits_get_resol(const cpl_propertylist * plist)
-{
-    return cpl_propertylist_get_double(plist,"ESO INS RESOL");
-}
-
 /**
 @brief set hdu keys 
 @param plist input propertylist
