@@ -74,12 +74,6 @@ sinfo_new_get_dummy_obj_sky_stacked(cpl_frameset* obj_set,
 cpl_frame* 
 sinfo_new_get_dummy_sky(cpl_frameset* obj_set);
 
-int 
-sinfo_new_sci_stk_frames(cpl_parameterlist* config,
-                         cpl_frameset** set,
-                         const char* recipe_id,
-             const char** pro_ctg_cube);
-
 int 
 sinfo_cub_stk_frames(cpl_parameterlist* config,
                      cpl_frameset** set,
