@@ -507,63 +507,7 @@ void sinfo_new_convert_ZEROs_to_0_for_images(cpl_image * im)
     return ;
 }
 
-/**
-@brief this function converts any ZEROs in a cube to 0
- @name sinfo_new_convert_ZEROs_to_0_for_cubes()
- @param cube input cube
- @param z_min
- @param z_max
- @param nothing 
-*/
-void sinfo_new_convert_ZEROs_to_0_for_cubes(cpl_imagelist * cube)
-{
-    int i ;
-    int inp=0;
 
-    if ( cube == NULL )
-    {
-        sinfo_msg_error("no input cube given!") ; 
-        return ;
-    }
-    inp=cpl_imagelist_get_size(cube);
-
-    for ( i = 0 ; i < inp ; i++ )
-    {
-      cpl_image* i_img=cpl_imagelist_get(cube,i);
-      sinfo_new_convert_ZEROs_to_0_for_images(i_img) ;
-      cpl_imagelist_set(cube,i_img,i);
-    }
-    return ;
-}
-
-
-/**
-@brief this function converts any ZEROs in a cube to 0
-  @name sinfo_new_convert_ZEROs_to_0_for_cubes_range()
-  @param cube input cube
-  @param z_min 
-  @param z_max
-  @return nothing 
- */
-void 
-sinfo_new_convert_ZEROs_to_0_for_cubes_range(cpl_imagelist * cube,
-                                             const int z_min,const int z_max)
-{
-    int i ;
-
-    if ( cube == NULL )
-    {
-        sinfo_msg_error("no input cube given!") ; 
-        return ;
-    }
-    for ( i = z_min ; i < z_max ; i++ )
-    {
-      cpl_image* i_img=cpl_imagelist_get(cube,i);
-      sinfo_new_convert_ZEROs_to_0_for_images(i_img) ;
-      cpl_imagelist_set(cube,i_img,i);
-    }
-    return ;
-}
 /**
 @brief this function converts any 0 in an image to ZEROs
  @name sinfo_new_convert_0_to_ZEROs_for_images()
@@ -621,60 +565,6 @@ void sinfo_new_convert_0_to_ZERO_for_cubes(cpl_imagelist * cube)
     return ;
 }
 
-
-/**
-@brief his function converts any 0 in a cube to ZERO
-   @name new_convert_0_to_ZEROs_for_cubes()
-   @param cube input cube
-   @param z_min  min z to be considered
-   @param z_max  max z to be considered
-   @return nothing
- */
-void 
-sinfo_new_convert_0_to_ZERO_for_cubes_range(cpl_imagelist * cube,
-                                            const int z_min,const int z_max)
-{
-    int i ;
-    //int inp=0;
-
-    if ( cube == NULL )
-    {
-        sinfo_msg_error("no input cube given!") ;
-        return ;
-    }
-    //inp=cpl_imagelist_get_size(cube);
-    for ( i = z_min ; i < z_max ; i++ )
-    {
-      cpl_image* i_img=cpl_imagelist_get(cube,i);
-      sinfo_new_convert_0_to_ZEROs_for_images(i_img) ;
-      cpl_imagelist_set(cube,i_img,i);
-    }
-    return ;
-}
-/**
-@brief this function multiplies each image value by -1
-@name new_invert_image()
- @param im input image
- @return inverted input image (overwritten)
- */
-void sinfo_new_invert(cpl_image * im)
-{
-    int i ;
-    int ilx=0;
-    int ily=0;
-    float* pidata=NULL;
-
-    ilx=cpl_image_get_size_x(im);
-    ily=cpl_image_get_size_y(im);
-    pidata=cpl_image_get_data(im);
-
-    for ( i = 0 ; i < (int) ilx*ily ; i++ )
-    {
-        pidata[i] = -pidata[i] ;
-    }
-    return ;
-}
-
 /**
 @brief  this routine determines the nearest integer to a specified real value
    @name sinfo_new_nint()
@@ -820,67 +710,9 @@ double * sinfo_new_xcorrel(
 /*  User supplied: None                                               */
 /*                                                                    */
 /*  PROGRAMMED BY: T.Haavie                                           */
-/*  DATE/VERSION: 88-07-06/1.0                                        */
+/*  DATE/VERSION: 88-07-06/1.0
+/*                                  */
 /*                                                                    */
-/**********************************************************************/
-double sinfo_nev_ille(double x[], double f[], int n, double z, int* flag)
-               /* PARAMETERS(input):                                  */
-/* double x[];     Abscissae values in the table.                      */
-/* double f[];     Function values in the table.                       */
-/* int n;         The number of elements in the table is n+1.         */
-/* double z;       Argument to be used in interpolation/extrapolation. */
-
-
-/*                PARAMETERS(input/output):                           */
-/* int *flag;    Flag parameter(output):                             */
-               /* = 0, n < 0 and/or eps < 0, should be positive+.     */
-               /* = 1, required rel.err. is not obtained.             */
-               /* = 2, required rel. err. is obtained.                */
-
-/* the computed estimate for the interpolated/extrapolated  value re- */
-/* turned through function name sinfo_nev_ille.                             */
-
-{
-        double p[11]; /* Array used for storing the new row elements */
-                       /* in the interpolation/extrapolation table.   */
-        double q[11]; /* Array used for storing the old row elements */
-                       /* in the interpolation/extrapolation table    */
-
-        double factor;
-        int m, k;
-
-       
-
-        if (n < 0 )
-        {
-                *flag = 0;
-                return(0.);
-        }
-
-
-        q[0] = f[0];               /* Set initial value in the table. */
-
-        for (k = 1; k <= n; k++)   /* k counts rows in the table.     */
-        {
-                p[0] = f[k];
-                for (m = 1; m <= k; m++) /* m counts element in row.  */
-                {
-                        factor = (z - x[k]) / (x[k] - x[k-m]);
-                        p[m] = p[m-1] + factor * (p[m-1] - q[m-1]);
-                }
-
-
-                for (m = 0; m <= k; m++) /* Shift old row to new row.  */
-                        q[m] = p[m];
-
-        } /* End of k-loop. */
-
-        *flag = 1;              /* Required rel.error is not obtained. */
-        return(p[n]);
-
-} /* End of sinfo_nev_ille(). */
-
-
 
 float sinfo_new_nev_ille(float x[], float f[], int n, float z, int* flag)
                /* PARAMETERS(input):                                  */
