@@ -272,14 +272,8 @@ reverse_tanh_kernel(double * data, int nn)
     unsigned long   n,
     mmax,
     m,
-    i, j,
-    istep ;
-    double  wtemp,
-    wr,
-    wpr,
-    wpi,
-    wi,
-    theta;
+    i, j;
+
     double  tempr,
     tempi;
 
@@ -299,13 +293,13 @@ reverse_tanh_kernel(double * data, int nn)
     }
     mmax = 2;
     while (n > mmax) {
-        istep = mmax << 1;
-        theta = 2 * PI_NUMB / mmax;
-        wtemp = sin(0.5 * theta);
-        wpr = -2.0 * wtemp * wtemp;
-        wpi = sin(theta);
-        wr  = 1.0;
-        wi  = 0.0;
+        unsigned long istep = mmax << 1;
+        double theta = 2 * PI_NUMB / mmax;
+        double wtemp = sin(0.5 * theta);
+        double wpr = -2.0 * wtemp * wtemp;
+        double wpi = sin(theta);
+        double wr  = 1.0;
+        double wi  = 0.0;
         for (m=1 ; m<mmax ; m+=2) {
             for (i=m ; i<=n ; i+=istep) {
                 j = i + mmax;
