@@ -133,9 +133,6 @@ double sinfo_new_determine_shift_by_correlation ( cpl_image * refImage,
     double       mean_offset2 ;
     /*int          magFactor ;*/
     int          maxlag ;
-    float      * refres ;
-    float      * myres ;
-    int          halfsearch ;
     int          delta ;
     double       xcorr_max ;
     /*float        arg ;*/
@@ -201,13 +198,13 @@ double sinfo_new_determine_shift_by_correlation ( cpl_image * refImage,
       line[row] = psdata[col+row*slx] ;
         }
 
-        myres = sinfo_function1d_filter_lowpass(line, convsize, 
+        float* myres = sinfo_function1d_filter_lowpass(line, convsize, 
                                                 LOW_PASS_GAUSSIAN, 3) ;
-        refres = sinfo_function1d_filter_lowpass(lineref, convsize, 
+        float* refres = sinfo_function1d_filter_lowpass(lineref, convsize, 
                                                  LOW_PASS_GAUSSIAN, 4) ;
 
         /*  now do a cross correlaton of both convolved spectral vectors */
-        halfsearch = convsize / 2 ;
+        int halfsearch = convsize / 2 ;
         result = sinfo_new_xcorrel( myres, convsize, refres, convsize, 
                                     halfsearch, &delta, &maxlag, &xcorr_max ) ;
 
@@ -239,6 +236,7 @@ double sinfo_new_determine_shift_by_correlation ( cpl_image * refImage,
         {
             sinfo_msg_error ("cannot allocate new Vector ") ;
             fclose(fp);
+            cpl_free ( offset2 ) ;
             return ZERO ;
         }
 
@@ -408,7 +406,7 @@ sinfo_new_fine_shift_image_in_spec_poly ( cpl_image * shiftedImage,
     float* corrected_spec=NULL ;
     float* xnum=NULL ;
 
-    float sum, new_sum ;
+    float new_sum ;
     float eval/*, dy*/ ;
     float * imageptr ;
     int row, col ;
@@ -477,7 +475,7 @@ sinfo_new_fine_shift_image_in_spec_poly ( cpl_image * shiftedImage,
         {
             corrected_spec[row] = 0. ;
         }
-        sum = 0. ;
+        float sum = 0. ;
         for ( row = 0 ; row < ily ; row++ )
         {
             spec[row] = pidata[col + row*ilx] ;
@@ -581,7 +579,7 @@ sinfo_new_fine_shift_image_in_spec_cubic_spline ( cpl_image * shiftedImage,
     float* corrected_spec=NULL ;
     float* xnum=NULL ;
     float* eval=NULL ;
-    float sum, new_sum ;
+    float new_sum ;
     int row, col ;
     int i ;
     int ilx=0;
@@ -624,7 +622,7 @@ sinfo_new_fine_shift_image_in_spec_cubic_spline ( cpl_image * shiftedImage,
 
     for ( col = 0 ; col < ilx ; col++ )
     {
-        sum = 0. ;
+        float sum = 0. ;
         for ( row = 0 ; row < ily ; row++ )
         {
             spec[row] = pidata[col + row*ilx] ;
@@ -700,13 +698,9 @@ cpl_imagelist * sinfo_align_cube_to_reference (cpl_imagelist * cube,
                                  int shift_indicator )
 {
     cpl_imagelist * retCube=NULL ;
-    cpl_image * shiftedIm=NULL ;
     cpl_image * fineShiftedIm=NULL ;
-    double shift=0 ;
-    double  sub_shift=0 ;
     int z=0;
     double * ker=NULL ;
-    cpl_image* img=NULL;
 
     if (cube == NULL)
     { 
@@ -728,6 +722,7 @@ cpl_imagelist * sinfo_align_cube_to_reference (cpl_imagelist * cube,
         if (ker == NULL)
         {
             sinfo_msg_error("kernel generation failure: aborting resampling") ;
+            cpl_imagelist_delete(retCube);
             return NULL ;
         }
     }
@@ -735,13 +730,16 @@ cpl_imagelist * sinfo_align_cube_to_reference (cpl_imagelist * cube,
     for ( z = 0 ; z < cpl_imagelist_get_size(cube) ; z++ )
     {
       /* first determine the shift by correlation with the reference image */
-      img=cpl_imagelist_get(cube,z);
+      cpl_image* img=cpl_imagelist_get(cube,z);
+      double shift;
       if (isnan( shift=sinfo_new_determine_shift_by_correlation(refIm,img)))
         { 
             sinfo_msg_error("error in sinfo_determineShiftByCorrelation()!") ;
             return NULL ;
         }
 
+        cpl_image * shiftedIm=NULL ;
+       double  sub_shift=0 ;
         if ( NULL == (shiftedIm = sinfo_new_shift_image_in_spec(img,shift,
                                                                 &sub_shift)) ) 
         { 
