@@ -218,9 +218,8 @@ parse_section_extraction(standstar_config * cfg, cpl_parameterlist* cpl_cfg)
 void
 sinfo_stdstar_free(standstar_config ** cfg)
 {
-    int i = 0;
     if ((*cfg) != NULL ) {
-        for (i = 0; i < (*cfg)->nframes; i++) {
+        for (int i = 0; i < (*cfg)->nframes; i++) {
             if ((*cfg)->inFrameList[i] != NULL ) {
                 cpl_free((*cfg)->inFrameList[i]);
                 (*cfg)->inFrameList[i] = NULL;
