@@ -184,11 +184,7 @@ int star_index_add(star_index* pindex, double RA, double DEC, const char* star_n
     return 0;
 }
 
-int start_index_get_size(star_index* pindex)
-{
-    return pindex ? pindex->index_size : 0;
-}
-
+/* not used */
 int star_index_remove_by_name(star_index* pindex, const char* starname)
 {
     int i = 0;
