@@ -375,13 +375,6 @@ void sinfo_svd_compare(float **a,int m,int n,float w[],float **v)
 #define NR_END 1
 #define FREE_ARG char*
 
-void sinfo_nerror(const char error_text[])
-{
-    fprintf(stderr,"Runtime ERROR ...\n");
-    fprintf(stderr,"%s\n",error_text);
-    fprintf(stderr,"exiting system \n");
-    return;
-}
 
 float *sinfo_vector(long nl, long nh)
 {
