@@ -91,6 +91,7 @@ sinfo_sort_table_1(cpl_table *t, const char *column, cpl_boolean reverse)
    This is a wrapper of @c cpl_table_sort(). @em column1 is the more
    significant column (i.e. values in @em column2 are compared, only if the
    values in @em column1 are equal).
+   TODO: not used
  */
 /*---------------------------------------------------------------------------*/
 cpl_error_code
@@ -221,27 +222,13 @@ sinfo_select_table_rows(cpl_table *t,  const char *column,
     return result;
 
 }
-
-/**
-   @brief    Deallocate an image and set the pointer to NULL
-   @param    p        parameter to deallocate
- */
-/*---------------------------------------------------------------------------*/
-/* TODO: not used */
-void sinfo_free_parameter(cpl_parameter **p) 
-{if(p){cpl_parameter_delete(*p);            *p = NULL;}}
-
-
-
 /**
    @brief    Deallocate an aperture and set the pointer to NULL
    @param    a        parameter to deallocate
  */
 /*---------------------------------------------------------------------------*/
-/* TODO: not used */
-void sinfo_free_apertures(cpl_apertures **a) 
+void sinfo_free_apertures(cpl_apertures **a)
 {if(a){cpl_apertures_delete(*a);            *a = NULL;}}
-/*---------------------------------------------------------------------------*/
 
 /*---------------------------------------------------------------------------*/
 /**
@@ -317,15 +304,7 @@ void sinfo_free_polynomial(cpl_polynomial **p)
 void sinfoni_free_matrix(cpl_matrix **m) 
 {if(m){cpl_matrix_delete(*m); *m = NULL;}}
 
-/*---------------------------------------------------------------------------*/
-/**
-   @brief    Deallocate a parameter list and set the pointer to NULL
-   @param    p        Parameter list to deallocate
- */
-/*---------------------------------------------------------------------------*/
-/* TODO: not used */
-void sinfo_free_parameterlist(cpl_parameterlist **p) 
-{if(p){cpl_parameterlist_delete(*p);    *p = NULL;}}
+
 /*----------------------------------------------------------------------------*/
 /**
    @brief    Deallocate a vector and set the pointer to NULL
@@ -462,14 +441,6 @@ sinfo_free_bivector(cpl_bivector **bv) {
     }
 }
 
-/*---------------------------------------------------------------------------*/
-/**
-   @brief    Deallocate a stats object and set the pointer to NULL
-   @param    s        Stats object to deallocate
- */
-/*---------------------------------------------------------------------------*/
-/* TODO: not used */
-void sinfo_free_stats(cpl_stats **s) {if(s){cpl_stats_delete(*s); *s = NULL;}}
 /*---------------------------------------------------------------------------*/
 /**
    @brief    Unwrap a vector and set the pointer to NULL
@@ -488,14 +459,4 @@ sinfo_unwrap_vector(cpl_vector **v) {if(v){cpl_vector_unwrap(*v); *v = NULL;}}
 void sinfo_unwrap_matrix(cpl_matrix **m) 
 {if(m){cpl_matrix_unwrap(*m); *m = NULL;}}
 
-/*---------------------------------------------------------------------------*/
-/**
-   @brief    Unwrap a bi-vector and set the pointer to NULL
-   @param    b        Bi-vector to deallocate
- */
-/*---------------------------------------------------------------------------*/
-/* TODO: not used */
-void sinfo_unwrap_bivector_vectors(cpl_bivector **b) 
-{if(b){cpl_bivector_unwrap_vectors(*b); *b = NULL;}}
-
 /**@}*/
