@@ -338,6 +338,64 @@ void sinfo_new_destroy_fit_params ( FitParams *** params )
     (*params)=NULL;
 }
 
+
+
+
+/**
+@brief dumps ASCII information to an allocated FitParams data structure
+@name dump_ascii_to_fit_params()
+@param params allocated dummy for the fit params
+@param filename
+@return params: filled FitParams object
+ */
+/* TODO: not used */
+void
+sinfo_new_dump_ascii_to_fit_params ( FitParams ** params, char * filename )
+{
+    FILE * fp ;
+    int i ;
+
+    if ( NULL == params )
+    {
+        sinfo_msg_error (" no fit parameters available!\n") ;
+        return ;
+    }
+
+    if ( NULL == filename )
+    {
+        sinfo_msg_error (" no filename available!\n") ;
+        return ;
+    }
+
+    if ( NULL == (fp = fopen ( filename, "r" ) ) )
+    {
+        sinfo_msg_error(" cannot open %s\n", filename) ;
+        return ;
+    }
+
+    for ( i = 0 ; i < params[0]->n_params ; i++ )
+    {
+        fscanf(fp, "%d %d %d %f %f %f %f %f %f %f %f %f\n",
+                        &params[i]->n_params,
+                        &params[i]->column,
+                        &params[i]->line,
+                        &params[i]->wavelength,
+                        &params[i]->fit_par[0],
+                        &params[i]->fit_par[1],
+                        &params[i]->fit_par[2],
+                        &params[i]->fit_par[3],
+                        &params[i]->derv_par[0],
+                        &params[i]->derv_par[1],
+                        &params[i]->derv_par[2],
+                        &params[i]->derv_par[3] ) ;
+    }
+    fclose(fp) ;
+}
+
+
+
+
+
 /**
 @brief dumps the fit parameters to an ASCII file
 @name sinfo_new_dump_fit_params_to_ascii()
@@ -388,57 +446,6 @@ void sinfo_new_dump_fit_params_to_ascii ( FitParams ** params, const char * file
     fclose(fp) ;
 }
 
-/**
-@brief dumps ASCII information to an allocated FitParams data structure
-@name dump_ascii_to_fit_params()
-@param params allocated dummy for the fit params 
-@param filename
-@return params: filled FitParams object
- */
-/* TODO: not used */
-void 
-sinfo_new_dump_ascii_to_fit_params ( FitParams ** params, char * filename )
-{
-    FILE * fp ;
-    int i ;
-
-    if ( NULL == params )
-    {
-        sinfo_msg_error (" no fit parameters available!\n") ;
-        return ;
-    }
-
-    if ( NULL == filename )
-    {
-        sinfo_msg_error (" no filename available!\n") ;
-        return ;
-    }
-
-    if ( NULL == (fp = fopen ( filename, "r" ) ) )
-    {
-        sinfo_msg_error(" cannot open %s\n", filename) ;
-        return ;
-    }
-
-    for ( i = 0 ; i < params[0]->n_params ; i++ )
-    {
-        fscanf(fp, "%d %d %d %f %f %f %f %f %f %f %f %f\n", 
-                        &params[i]->n_params,
-                        &params[i]->column,
-                        &params[i]->line,
-                        &params[i]->wavelength,
-                        &params[i]->fit_par[0],
-                        &params[i]->fit_par[1],
-                        &params[i]->fit_par[2],
-                        &params[i]->fit_par[3],
-                        &params[i]->derv_par[0],
-                        &params[i]->derv_par[1],
-                        &params[i]->derv_par[2],
-                        &params[i]->derv_par[3] ) ;
-    }
-    fclose(fp) ;
-}
-
 /**
 @brief determines the pixel shift between the line list and the real image
 @name sinfo_new_find_lines()
@@ -834,53 +841,6 @@ int sinfo_new_find_lines(cpl_image * lineImage,
     return 0 ;
 }
 
-/**
-@brief reads the line data of the calibration lamps
-@name sinfo_new_read_list()
-@param listname name of the list file, arrays to store the wavelength 
-                and the intensities of the emission lines
-@param  lineCenter 
-@param lineIntensity
- */
-/* TODO: not used */
-int 
-sinfo_new_read_list( char * listname, 
-                     float * lineCenter, 
-                     float * lineIntensity )
-{
-    FILE * fp ;
-    int i, n_lines ;
-
-    if ( NULL == lineCenter )
-    {
-        sinfo_msg_error(" lineCenter array is not allocated\n") ;
-        return -1 ;
-    }
-
-    if ( NULL == lineIntensity )
-    {
-        sinfo_msg_error(" lineIntensity array is not allocated\n") ;
-        return -1 ;
-    }
-
-    if ( NULL == (fp = fopen ( listname, "r" ) ) )
-    {
-        sinfo_msg_error(" cannot open %s\n", listname) ;
-        return -1 ;
-    }
-
-    i = 0 ;
-    while ( fscanf( fp, "%f %f", &lineCenter[i], &lineIntensity[i] ) != EOF )
-    {
-        i ++ ;
-    }
-    n_lines = i ;
-    fclose(fp) ;
-
-    return n_lines ;
-}
-
-
 /**
 @brief fits a Gaussian to a 1-dimensional slice of an image
 @name sinfo_new_line_fit()
@@ -1650,659 +1610,6 @@ float sinfo_new_coefs_cross_fit ( int      n_columns,
 }
 
 
-/**
-@brief determines a wavelength calibration map
-@name sinfo_new_wave_map()
-@param lineImage:    image from a calibration emission lamp,
-@param bcoefs:       transformed fit coefficients
-@param n_a_fitcoefs: number of fit coefficients for the single  
-                     column fits lambda-position
-@param n_b_fitcoefs: number of fit coefficients for the fits of
-                     the single a coefficients across the columns
-@param wavelength:   wavelength list from lamp file
-@param intensity:    corresponding line intensity from line list
-@param n_lines:      number of lines in the list
-@param magFactor:    magnifying factor of the image for FFT
-@return wavelength calibration map image.
-@doc this routine determines a wavelength calibration map frame 
-                   associating a wavelength value to 
-     each pixel by using the fit coefficients determined before.
- */
-/* TODO: not used */
-cpl_image * sinfo_new_wave_map( cpl_image * lineImage,
-                                float   ** bcoefs,
-                                int        n_a_fitcoefs,
-                                int        n_b_fitcoefs,
-                                float    * wavelength,
-                                float    * intensity,
-                                int        n_lines,
-                                int        magFactor)
-{
-    cpl_image * retImage ;
-    float cenpos, cenpix ;
-    float centreval, centrepix, wavelag ;
-    float  pixvalue ;
-
-    int i, j, k, l/*, m*/, line, col, row, found, sign ;
-    int var, maxlag, cmin, cmax, offset ;
-    double * result ;
-
-    float angst ;
-    double xcorr_max ;
-    int delta ;
-
-    double* z=NULL ;
-    double* a=NULL ;
-    double*  wave=NULL ;
-    float* emline=NULL ;
-    float* spec=NULL ;
-    int ilx=0;
-    int ily=0;
-    /*
-    int olx=0;
-    int oly=0;
-     */
-    float* pidata=NULL;
-    float* podata=NULL;
-
-
-    gsl_poly_complex_workspace * w ;
-
-    if ( NULL == lineImage )
-    {
-        sinfo_msg_error("no image given\n") ;
-        return NULL ;
-    }
-    ilx=cpl_image_get_size_x(lineImage);
-    ily=cpl_image_get_size_y(lineImage);
-    pidata=cpl_image_get_data_float(lineImage);
-
-    if ( NULL == wavelength || n_lines <= 0 )
-    {
-        sinfo_msg_error("no wavelength list given\n") ;
-        return NULL ;
-    }
-
-    if ( NULL == intensity )
-    {
-        sinfo_msg_error("no intensity list given\n") ;
-        return NULL ;
-    }
-
-    if ( NULL == bcoefs )
-    {
-        sinfo_msg_error("no coefficients given\n") ;
-        return NULL ;
-    }
-
-    if ( magFactor <= 1 )
-    {
-        sinfo_msg_error("wrong magnifying factor given\n") ;
-        return NULL ;
-    }
-
-    /* allocate memory */
-    if ( NULL == ( retImage = cpl_image_new( ilx, ily,CPL_TYPE_FLOAT ) ))
-    {
-        sinfo_msg_error("cannot allocate a new image\n");
-        return NULL ;
-    }
-    /*
-    olx=cpl_image_get_size_x(retImage);
-    oly=cpl_image_get_size_y(retImage);
-     */
-    podata=cpl_image_get_data_float(retImage);
-
-
-    var    = (magFactor - 1)*(magFactor - 1) ;
-    offset = ily * (magFactor/4 + 1) ;
-
-    /* find out if Angstroem or microns are used */
-    if ( wavelength[0] > 10000. )
-    {
-        /* Angstroem */
-        angst = 10000. ;
-    }
-    else if ( wavelength[0] > 1000. && wavelength[0] < 10000. )
-    {
-        /* nanometers */
-        angst = 1000. ;
-    }
-    else
-    {
-        /* microns */
-        angst = 1. ;
-    }
-
-    z=cpl_calloc(2*(n_a_fitcoefs - 1),sizeof(double)) ;
-    a=cpl_calloc(n_a_fitcoefs,sizeof(double));
-    wave=cpl_calloc(n_lines,sizeof(double)) ;
-    emline=cpl_calloc(2*magFactor*ily,sizeof(float));
-    spec=cpl_calloc(2*magFactor*ily,sizeof(float)) ;
-
-    /* go through the image columns */
-    for ( col = 0 ; col < ilx ; col++ )
-    {
-        /* initialize the emline array for each column */
-        for ( i = 0 ; i < 2*magFactor*ily ; i++ )
-        {
-            emline[i] = 0. ;
-        }
-        float col_off = (float)col - (float)(ilx-1)/2. ;
-
-        /* determine the coefficients by using the given bcoefs */
-        for ( i = 0 ; i < n_a_fitcoefs ; i++ ) 
-        {
-            /* initialize coefficients and solution */
-            a[i] = 0. ;
-            if (i < n_a_fitcoefs-1)
-            {
-                z[2*i] = 0. ;
-                z[2*i+1] = 0. ;
-            }
-            for ( j = 0 ; j < n_b_fitcoefs ; j++ )
-            {
-                a[i] += bcoefs[i][j] * pow(col_off, j) ;
-            }
-        }
-        float a_initial = a[0] ;
-
-        /* go through the lines and generate an artificial spectrum */
-        for ( line = 0 ; line < n_lines ; line++ )
-        {
-            /* go from Angstroem to micron */
-            wave[line] = wavelength[line]/angst ;
-
-            /* ---------------------------------------------------------------
-             * solve the polynomial for the exact offset of the line that means
-             * find the root of the polynomial of order n_fitcoefs - 1
-             */
-            a[0] = a_initial - wave[line] ;
-
-            if(NULL==(w=sinfo_gsl_poly_complex_workspace_alloc(n_a_fitcoefs)))
-            {
-                sinfo_msg_error("could not allocate complex workspace!") ;
-                cpl_image_delete(retImage) ;
-                return NULL ;
-            }
-            if (-1 == sinfo_gsl_poly_complex_solve(a, n_a_fitcoefs, w, z))
-            {
-                sinfo_msg_error("sinfo_gsl_poly_complex_solve did not work!") ;
-                cpl_image_delete(retImage) ;
-                return NULL ;
-            }
-            sinfo_gsl_poly_complex_workspace_free(w) ;
-
-
-            j = 0 ;
-            found = -1 ;
-            for ( i = 0 ; i < n_a_fitcoefs - 1  ; i++ )
-            {
-                /* test for appropriate solution */
-                if( z[2*i] > (-1.)*(float) ily/2. && 
-                                z[2*i] < (float)ily/2. && z[2*i+1] == 0. )
-                {
-                    found = 2*i ;
-                    j ++ ;
-                }
-                else
-                {
-                    continue ;
-                } 
-            }
-            if ( j == 0 )
-            {
-                sinfo_msg_warning("no offset solution found "
-                                "for line %d in column %d\n", line, col) ;
-                continue ;
-            } 
-            else if ( j == 1 )
-            {
-                cenpos = z[found] + (float) ily /2. ;
-            }
-            else
-            {
-                sinfo_msg_warning("two or more offset solutions found "
-                                "for line %d in column %d\n", line, col) ;
-                continue ;
-            }
-
-            /*---------------------------------------------------------------
-             * magnify image by the given factor add an additional offset 
-             */
-            cenpix = cenpos * (float) magFactor + (float) offset ;  
-
-            /* determine max and min pixel limits over 
-               which line should be convolved */
-            cmin = (sinfo_new_nint(cenpix) - (var-1)) > 0 ? 
-                            sinfo_new_nint(cenpix) - (var-1) : 0 ;
-            cmax = (sinfo_new_nint(cenpix) + (var-1)) < 2*magFactor * ily ? 
-                            sinfo_new_nint(cenpix) + (var-1) :  2*magFactor * ily ;
-
-            /* convolve neon lines with Gaussian function */
-            for ( j = cmin ; j < cmax ; j++ )
-            {
-                emline[j] += intensity[line] * 
-                                exp((double)(-0.5*(j-cenpix)*(j-cenpix))/(double)var) ;
-            }
-        }
-
-        /*--------------------------------------------------------------------- 
-         * for each column, map the image data points onto an magFactor times 
-           bigger element grid for FFT in the cross sinfo_new_correlation, 
-           first initialize the two helping arrays for each new column.
-         */
-        for ( k = 0 ; k < 2*magFactor * ily ; k++ )
-        {
-            spec[k] =  0. ;
-        }
-
-        /* now take the image data points of the column and put them 
-           into the spec array */
-        for ( row = 0 ; row < ily ; row++ ) /* go through the column */
-        {
-            /* insert 8 values for each image row (magnification) and 
-               add same offset as for emline array */
-            for ( l = 0 ; l < magFactor ; l++ )   
-            {
-                /* set bad pixels or negative values to zero */
-                if (!isnan(pidata[col + row * ilx]) &&
-                                (pidata[col + row * ilx] > 0.))
-                {
-                    spec[offset + l + (row * magFactor)] = 
-                                    pidata[col + row * ilx] ;
-                }
-                else
-                {
-                    spec[offset + l + (row * magFactor)] = 0. ;
-                }
-            }
-        }
-
-        /* now call the cross sinfo_new_correlation routine */
-        if (NULL == (result = sinfo_new_xcorrel(spec, 2*magFactor * ily, 
-                        emline, 2*magFactor * ily,
-                        magFactor * ily, &delta,
-                        &maxlag, &xcorr_max)) )
-        {
-            sinfo_msg_warning ("cross sinfo_new_correlation did not work,"
-                            " col: %d is set ZERO\n", col) ;
-            for ( row = 0 ; row < ily ; row++ )
-            {
-                podata[col + row * ilx] = ZERO ;
-            }
-            continue ;
-        }
-
-        if ( xcorr_max <= 0. )
-        {
-            sinfo_msg_warning ("cross sinfo_new_correlation sum is negative,"
-                            " col: %d is set ZERO\n", col) ;
-            for ( row = 0 ; row < ily ; row++ )
-            {
-                podata[col + row * ilx] = ZERO ;
-            }
-            cpl_free(result) ;
-            continue ;
-        }
-
-        wavelag = (float) -delta / (float) magFactor ;
-        if ( fabs(wavelag) > (float)ily/20. )
-        {
-            sinfo_msg_warning("wave lag too big, col: %d is set ZERO\n", col) ;
-            for ( row = 0 ; row < ily ; row++ )
-            {
-                podata[col + row * ilx] = ZERO ;
-            }
-            cpl_free(result) ;
-            continue ;
-        }
-
-        /*-------------------------------------------------------------------- 
-         * determine new zero order coefficient centreval, of which the 
-           formula is determined by setting equal a polynomial shifted by 
-           wavelag with the same higher order coefficients and set the new 
-           zero order coefficient to get both sides of the equation 
-           approximately equal.
-         */ 
-        centreval = a_initial ;
-        for ( i = 1 ; i < n_a_fitcoefs ; i++ )
-        {
-            if ( i%2 == 0 )
-            {
-                sign = -1 ;
-            }
-            else
-            {
-                sign = 1 ;
-            }
-            centreval += (float)sign * a[i]*pow(wavelag, i) ;
-        }
-
-        /* prepare to write out wavelength as pixel values */
-        for ( row = 0 ; row < ily ; row++ )
-        {
-            centrepix = (float)row - ((float)ily - 1.)/2. ;
-            pixvalue = 0. ;
-            for ( i = 1 ; i < n_a_fitcoefs ; i++ )
-            {
-                pixvalue += a[i]*pow(centrepix, i) ; 
-            }
-            podata[col + row * ilx] = centreval + pixvalue ; 
-        }
-        cpl_free(result) ;   
-    }
-
-
-
-    cpl_free(z) ;
-    cpl_free(a) ;
-    cpl_free(wave) ;
-    cpl_free(emline) ;
-    cpl_free(spec) ;
-
-    return retImage ;
-}                    
-
-/**
-@brief
-@name sinfo_new_wavelength_calibration()
-@param image:        merged image from a calibration emission lamp,
-@param wave:         wavelength array read from the wavelength list
-@param n_lines:      number of lines in the wavelength list
-@param row_clean: resulting list of the row indices but without the
-                     lines that are too close to each other for the fit
-                     output of sinfo_findLines()
-@param wavelength_clean: corrected wavelength list corresponding to
-                     the row_clean array
-                     output of sinfo_findLines()
-@param n_found_lines: output of sinfo_findLines(): total number of 
-                      found emission lines
-@param dispersion:   dispersion of spectrum: micron per pixel
-@param halfWidth:    half width of the box where the line must sit
-@param minAmplitude: minimum amplitude of the Gaussian to do the fit
-@param max_residual: maximum residual value, beyond that value
-                     the polynomial lambda-position fit is rejected.
-@param fwhm:         first guess for the full width of half maximum
-                     of the sinfo_gaussian line fit
-@param n_a_fitcoefs: number of fit coefficients for the single
-                     column fits: lambda-position
-@param n_b_fitcoefs: number of fit coefficients for the fits of
-                     the single a coefficients across the columns
-@param sigmaFactor:  factor of the standard deviation of the determined
-                     polynomial coefficients of the columns beyond
-                     which these coefficients are not used to carry out
-                     the polynomial fit across the columns.
-@param pixel_tolerance: maximum tolerated difference between estimated
-                     and fitted line positions.
-@return 0 if all went o.k., -1 if something went wrong.
-        # bcoefs: array of cooefficients of the polynomial fit 
-                  across the columns.
-        # par: array of the resulting FitParams data structure
-@doc this routine takes an image from a calibration emission lamp and 
-     delivers the fit coefficients of a polynomial fit across the columns 
-     of the coefficients of the polynomial line position fits as output. 
-     Furthermore it delivers an array of the fit parameters as output. This 
-     routine expects Nyquist sampled spectra (either an interleaved image 
-     or an image convolved with an
-     appropriate function in spectral direction)
- */
-/* TODO: not used */
-int sinfo_new_wavelength_calibration( cpl_image   * image,
-                                      FitParams ** par ,
-                                      float     ** bcoefs,
-                                      float      * wave,
-                                      int          n_lines,
-                                      int       ** row_clean,
-                                      float     ** wavelength_clean,
-                                      int        * n_found_lines,
-                                      float        dispersion,
-                                      int          halfWidth,
-                                      float        minAmplitude,
-                                      float        max_residual,
-                                      float        fwhm,
-                                      int          n_a_fitcoefs,
-                                      int          n_b_fitcoefs,
-                                      float        sigmaFactor,
-                                      float        pixel_tolerance )
-
-{
-    int          i, j;
-    /* int k ; */
-    int          n_fit ;
-    int          n_reject ;
-    float     *  acoefs ;
-    float     *  dacoefs ;
-    float     ** abuf ;
-    float     ** dabuf ;
-
-
-    /*float     *  mem ;*/
-    int lx=0;
-    int ly=0;
-    /* float* pdata=NULL; */
-
-    if (  NULL == image )
-    {
-        sinfo_msg_error("no image given\n") ;
-        return -1 ;
-    }
-    lx=cpl_image_get_size_x(image);
-    ly=cpl_image_get_size_y(image);
-    /* pdata=cpl_image_get_data_float(image); */
-
-    if ( par == NULL )
-    {
-        sinfo_msg_error("no fit parameter data structure given\n") ;
-        return -1 ;
-    }
-    if ( wave == NULL )
-    {
-        sinfo_msg_error("no wavelength list given\n") ;
-        return -1 ;
-    }
-    if ( n_lines <= 0 )
-    {
-        sinfo_msg_error("impossible number of lines in line list given\n") ;
-        return -1 ;
-    }
-    if ( row_clean == NULL )
-    {
-        sinfo_msg_error("no row_clean array given\n") ;
-        return -1 ;
-    }
-    if ( wavelength_clean == NULL )
-    {
-        sinfo_msg_error("no wavelength_clean array given\n") ;
-        return -1 ;
-    }
-
-    if ( dispersion == 0. )
-    {
-        sinfo_msg_error("impossible dispersion given\n") ;
-        return -1 ;
-    }
-
-    if ( halfWidth <= 0 || halfWidth > ly/2 )
-    {
-        sinfo_msg_error("impossible half width of the fitting box given\n") ;
-        return -1 ;
-    }
-    if ( minAmplitude < 1. )
-    {
-        sinfo_msg_error("impossible minimal amplitude\n") ;
-        return -1 ;
-    }
-
-    if ( max_residual <= 0. || max_residual > 1. )
-    {
-        sinfo_msg_error("impossible max_residual given\n") ;
-        return -1 ;
-    }
-
-    if ( fwhm <= 0. || fwhm > 10. )
-    {
-        sinfo_msg_error("impossible fwhm given\n") ;
-
-        return -1 ;
-    }
-
-    if ( n_a_fitcoefs <= 0 || n_a_fitcoefs > 9 )
-    {
-        sinfo_msg_error("unrealistic n_a_fitcoefs given\n") ;
-        return -1 ;
-    }
-
-    if ( n_b_fitcoefs <= 0 || n_b_fitcoefs > 9 )
-    {
-        sinfo_msg_error(" unrealistic n_b_fitcoefs given\n") ;
-        return -1 ;
-    }
-    if ( sigmaFactor <= 0. )
-    {
-        sinfo_msg_error(" impossible sigmaFactor given\n") ;
-        return -1 ;
-    }
-
-    /* initialize the variables */
-    n_reject = 0 ;
-    n_fit = 0 ;
-
-    /* fit each found line by using a Gaussian function and determine the 
-       exact position */
-    if ( 0 > (n_fit = sinfo_new_fit_lines( image , par, fwhm, 
-                    n_found_lines, row_clean,
-                    wavelength_clean,
-                    halfWidth, minAmplitude )) )
-    {
-        sinfo_msg_error(" cannot fit the lines, "
-                        "error code of sinfo_fitLines: %d\n", n_fit) ;
-        return -1 ;
-    }
-
-    /* first check for faked lines like bad pixels */
-    if ( -1 == sinfo_new_check_for_fake_lines (par, dispersion, 
-                    wavelength_clean, row_clean,
-                    n_found_lines,
-                    lx, pixel_tolerance) )
-    {
-        sinfo_msg_error("cannot fit the lines, "
-                        "error code of sinfo_fitLines: %d", n_fit) ;
-        return -1 ;
-    }
-
-    /* allocate memory */
-    if (NULL == (acoefs = (float*) cpl_calloc (n_a_fitcoefs, sizeof(float*))) ||
-                    NULL == (dacoefs = (float*)cpl_calloc (n_a_fitcoefs, sizeof(float*))) ||
-                    NULL == (abuf = (float**) cpl_calloc (n_a_fitcoefs, sizeof(float*))) ||
-                    NULL == (dabuf = (float**) cpl_calloc (n_a_fitcoefs, sizeof(float*))) )
-    {
-        sinfo_msg_error(" cannot allocate memory\n") ;
-        return -1 ;
-    }
-
-    for ( i = 0 ; i < n_a_fitcoefs ; i++ )
-    {
-        if ( NULL == (abuf[i] = (float*) cpl_calloc(lx, sizeof(float))) ||
-                        NULL == (dabuf[i] = (float*) cpl_calloc(lx, sizeof(float))) )
-        {
-            sinfo_msg_error(" cannot allocate memory\n") ;
-            cpl_free(abuf) ;
-            cpl_free(dabuf) ;
-            return -1 ;
-        }
-    }
-
-    /* fit wavelengths to the corresponding found positions for each column */
-    /* k = 0 ; */
-
-    for ( i = 0 ; i < lx ; i++ )
-    {
-        int zeroind = 0 ;
-        float chisq_poly;
-        if ( FLT_MAX == (chisq_poly = sinfo_new_polyfit( par, i, 
-                        n_found_lines[i],
-                        ly, dispersion,
-                        max_residual, acoefs,
-                        dacoefs, &n_reject,
-                        n_a_fitcoefs)) )
-        {
-            /*
-           sinfo_msg_warning (" error in polyfitt in column: %d\n", i) ;
-             */
-            for ( j = 0 ; j < n_a_fitcoefs ; j++ )
-            {
-                acoefs[j] = ZERO ;
-                dacoefs[j] = ZERO ;
-            }
-        }
-
-        for ( j = 0 ; j < n_a_fitcoefs ; j++ )
-        {
-            if ( acoefs[0] <= 0. || acoefs[1] ==0. ||
-                            dacoefs[j] == 0. || isnan(acoefs[j]) )
-            {
-                zeroind = 1 ;
-
-            }
-        }
-        for ( j = 0 ; j < n_a_fitcoefs ; j++ )
-        {
-            if ( zeroind == 0 )
-            {
-                abuf[j][i]  = acoefs[j] ;
-                dabuf[j][i] = dacoefs[j] ;
-            }
-            else
-            {
-                abuf[j][i]  = ZERO ;
-                dabuf[j][i] = ZERO ;
-            }
-        }
-    }
-
-    /* fit each acoefs across the columns to smooth the result */
-    for ( i = 0 ; i < n_a_fitcoefs ; i++ )
-    {
-        float chisq_cross;
-        if ( FLT_MAX == (chisq_cross = sinfo_new_coefs_cross_fit(lx, 
-                        abuf[i],
-                        dabuf[i],
-                        bcoefs[i],
-                        n_b_fitcoefs,
-                        sigmaFactor)))
-        {
-            sinfo_msg_error (" cannot carry out the fitting of coefficients"
-                            " across the columns, for the coefficient with"
-                            " index: %d\n", i) ;
-            for ( i = 0 ; i < n_a_fitcoefs ; i++ )
-            {
-                cpl_free (abuf[i]) ;
-                cpl_free (dabuf[i]) ;
-            }
-            cpl_free ( acoefs ) ;
-            cpl_free ( dacoefs ) ;
-            cpl_free ( abuf ) ;
-            cpl_free ( dabuf ) ;
-            return -1 ;
-        }
-    }
-
-    /* free all allocated memory */
-    for ( i = 0 ; i < n_a_fitcoefs ; i++ )
-    {
-        cpl_free (abuf[i]) ;
-        cpl_free (dabuf[i]) ;
-    }
-    cpl_free ( acoefs ) ;
-    cpl_free ( dacoefs ) ;
-    cpl_free ( abuf ) ;
-    cpl_free ( dabuf ) ;
-
-    return 0 ;   
-}
-
-
 /**
 @brief
 @name sinfo_new_convolve_image_by_gauss()
@@ -2821,8 +2128,7 @@ cpl_image * sinfo_new_defined_resampling( cpl_image * image,
                 half_width = (int)(n_params/2) ;
             }
 
-
-            if ( isnan(imagecol[testrow]) )
+            if ( testrow > -1 && isnan(imagecol[testrow]) )
             {
                 for ( i = row-half_width ; i < row-half_width+n_params ; i++ )
                 { 
