@@ -63,7 +63,6 @@ sinfo_new_fit_params( int n_params ) ;
 
 void 
 sinfo_new_destroy_fit_params ( FitParams *** params ) ;
-
 /**
    @name   sinfo_new_dump_fit_params_to_ascii()
    @memo   dumps the fit parameters to an ASCII file
@@ -72,17 +71,9 @@ sinfo_new_destroy_fit_params ( FitParams *** params ) ;
    @return filled ASCII file
 */
 
-void 
+void
 sinfo_new_dump_fit_params_to_ascii ( FitParams ** params, const char * filename ) ;
 
-/**
-   @name   sinfo_new_dump_ascii_to_fit_params()
-   @memo   dumps ASCII information to an allocated FitParams data structure
-   @param  params allocated dummy for the fit params
-   @param  filename
-   @return params: filled FitParams object
-*/
-
 void 
 sinfo_new_dump_ascii_to_fit_params ( FitParams ** params, char * filename ) ;
 
@@ -142,19 +133,6 @@ sinfo_new_find_lines(cpl_image * lineImage,
                float      sigma,
                int      * sum_lines ) ;
 
-/**
-   @name   sinfo_new_read_list()
-   @memo   reads the line data  of the calibration lamps
-   @param  listname name of the list file, arrays to store the wavelength
-                    and the intensities of the emission lines
-   @return number of lines in file
-*/
-
-int 
-sinfo_new_read_list( char * listname, 
-                     float * lineCenter, 
-                     float * lineIntensity ) ;
-
 /**
    @name    sinfo_new_line_fit()
    @param   mergedImage image of a calibration emission lamp,
@@ -290,96 +268,6 @@ sinfo_new_coefs_cross_fit ( int      n_columns,
                       int      n_fitcoefs,
                       float    sigma_factor ) ;
 
-/**
-   @name   sinfo_new_wave_map()
-   @param  lineImage    image from a calibration emission lamp,
-   @param  bcoefs       transformed fit coefficients
-   @param  n_a_fitcoefs number of fit coefficients for the single
-                        column fits lambda-position
-   @param  n_b_fitcoefs number of fit coefficients for the fits of
-                        the single a coefficients across the columns
-   @param  wavelength   wavelength list from lamp file
-   @param  intensity    corresponding line intensity from line list
-   @param  n_lines      number of lines in the list
-   @param  magFactor    magnifying factor of the image for FFT
-   @return wavelength calibration map image.
-   @memo   determines a wavelength calibration map frame associating a 
-           wavelength value to each pixel by using the fit coefficients 
-           determined before.
-*/
-
-cpl_image * 
-sinfo_new_wave_map(cpl_image * lineImage,
-                    float   ** bcoefs,
-                    int        n_a_fitcoefs,
-                    int        n_b_fitcoefs,
-                    float    * wavelength,
-                    float    * intensity,
-                    int        n_lines,
-                    int        magFactor) ;
-
-/**
-   @name  sinfo_new_wavelength_calibration()
-   @memo  takes an image from a calibration emission lamp and delivers the fit 
-          coefficients of a polynomial fit across the columns of the 
-          coefficients of the polynomial line position fits as output. 
-          Furthermore it delivers an array of the fit parameters as output. 
-          This routine expects Nyquist sampled spectra (either an interleaved 
-          image or an image convolved with an appropriate function in spectral 
-          direction).
-
-   @param image merged image from a calibration emission lamp,
-   @param  par array of the resulting FitParams data structure
-   @param  bcoefs array of cooefficients of the polynomial fit 
-           across the columns.
-   @param wave  wavelength array read from the wavelength list
-   @param n_lines  number of lines in the wavelength list
-   @param row_clean resulting list of the row indices but without the
-                    lines that are too close to each other for the fit
-                    output of sinfo_findLines()
-   @param wavelength_clean corrected wavelength list corresponding to
-                           the row_clean array output of sinfo_findLines()
-   @param n_found_lines output of sinfo_findLines(): total number of 
-                        found emission lines
-   @param dispersion   dispersion of spectrum: micron per pixel
-   @param halfWidth    half width of the box where the line must sit
-   @param minAmplitude minimum amplitude of the Gaussian beyond which
-                       the fit is carried out
-   @param max_residual maximum residual value, beyond that value
-                       the polynomial lambda-position fit is rejected.
-   @param fwhm         first guess for the full width of half maximum
-                       of the sinfo_gaussian line fit
-   @param n_a_fitcoefs number of fit coefficients for the single
-                       column fits: lambda-position
-   @param n_b_fitcoefs number of fit coefficients for the fits of
-                       the single a coefficients across the columns
-   @param sigmaFactor  factor of the standard deviation of the determined
-                       polynomial coefficients of the columns beyond
-                       which these coefficients are not used to carry out
-                       the polynomial fit across the columns.
-   @param pixel_tolerance maximum tolerated difference between estimated
-                          and fitted line positions.
-   @return  0 if all went o.k., -1 if something went wrong.
-  */
-
-int 
-sinfo_new_wavelength_calibration(cpl_image   * image,
-                           FitParams ** par ,
-                           float     ** bcoefs,
-                           float      * wave,
-                           int          n_lines,
-                           int       ** row_clean,
-                           float     ** wavelength_clean,
-                           int        * n_found_lines,
-                           float        dispersion,
-                           int          halfWidth,
-                           float        minAmplitude,
-                           float        max_residual,
-                           float        fwhm,
-                           int          n_a_fitcoefs,
-                           int          n_b_fitcoefs,
-                           float        sigmaFactor,
-               float        pixel_tolerance ) ;
 
 /**
    @name     sinfo_new_convolve_image_by_gauss()
