@@ -166,8 +166,7 @@ parse_section_frames ( wave_config * cfg,cpl_parameterlist* cpl_cfg, cpl_framese
     char band[FILE_NAME_SZ];
     int ins_set=0;
     int nraw=0;
-    cpl_parameter* p=NULL;
-    cpl_table* drs_tab=NULL;
+
     wcal* w=sinfo_wcal_new();
     int check=0;
 
@@ -247,7 +246,7 @@ parse_section_frames ( wave_config * cfg,cpl_parameterlist* cpl_cfg, cpl_framese
     {
         frame = cpl_frameset_find ( sof,DRS_SETUP_WAVE );
         strcpy ( cfg -> drs_setup,cpl_frame_get_filename ( frame ) );
-        drs_tab = cpl_table_load ( cfg->drs_setup,1,0 );
+        cpl_table* drs_tab = cpl_table_load ( cfg->drs_setup,1,0 );
         w->wstart=cpl_table_get_double ( drs_tab,"W_START",ins_set,&check );
         w->wgdisp1=cpl_table_get_double ( drs_tab,"W_DISP1",ins_set,&check );
         w->wgdisp2=cpl_table_get_double ( drs_tab,"W_DISP2",ins_set,&check );
@@ -267,7 +266,7 @@ parse_section_frames ( wave_config * cfg,cpl_parameterlist* cpl_cfg, cpl_framese
         cfg -> guessBeginWavelength = w->wstart;
         cfg -> guessDispersion1 =  w->wgdisp1;
         cfg -> guessDispersion2 =  w->wgdisp2;
-        p = cpl_parameterlist_find ( cpl_cfg, "sinfoni.wavecal.half_width" );
+        cpl_parameter* p = cpl_parameterlist_find ( cpl_cfg, "sinfoni.wavecal.half_width" );
         if ( sinfo_parameter_get_default_flag ( p ) == 0 )
         {
             /*         cpl_msg_info(cpl_func, "param sinfoni.wavecal.half_width - using value from DRS [%i]", w->hw);*/
