@@ -397,16 +397,23 @@ int kappa_sigma_gauss_narrow_test()
 	const double SIGNAL_LEVEL = 50;
 	const double SIGNAL_NOISE_LEVEL = 5;
 	const double kappa = 3;
+	int z = 0;
 	int pOffsetX[nCubes];
 	int pOffsetY[nCubes];
-	int z = 0;
-	memset(&pOffsetX[0], 0, nCubes * sizeof(pOffsetX[0]));
-	memset(&pOffsetY[0], 0, nCubes * sizeof(pOffsetY[0]));
-	cpl_imagelist* ppCubes[nCubes];
+	//cpl_imagelist* ppCubes[nCubes];
+	cpl_imagelist** ppCubes=NULL;
+	ppCubes=cpl_calloc(nCubes, sizeof(cpl_imagelist*));
+	/* we need to initialise all variables */
+	for(int i = 0; i< nCubes ; i++) {
+	    pOffsetX[i] = 0;
+	    pOffsetY[i] = 0;
+	    exptimes[i]=1;
+	    ppCubes[i]= NULL;
+	}
 
 	cpl_imagelist* ilResult = cpl_imagelist_new();
 	cpl_assert(ilResult);
-	cpl_image* imResult = 0;
+	cpl_image* imResult = NULL;
 	check_nomsg(imResult = cpl_image_new(sizeX, sizeY, CPL_TYPE_DOUBLE));
 	check_nomsg(cpl_imagelist_set(ilResult, imResult ,0));
 
@@ -484,6 +491,7 @@ int kappa_sigma_gauss_narrow_test()
 	{
 		cpl_imagelist_delete(ppCubes[z]);
 	}
+	cpl_free(ppCubes);
 	return 0;
 	cleanup:
 	cpl_assert(!"error in cpl function");
