@@ -209,7 +209,7 @@ test_psf(void)
   double m2=SINFO_TEST_STREHL_M2;
   double w=2.2e-6;
   //double p1=0.0125;
-  double p2=0.0250;
+  //double p2=0.0250;
   double p3=0.0500;
   //double p4=0.100;
  
@@ -353,7 +353,7 @@ test_strehl_one(void)
 
 
     piqe=cpl_bivector_get_x_data(iqe1);
-    //*star_peak=piqe[5];
+    //  *star_peak=piqe[5];
     xpos=piqe[0];
     ypos=piqe[1];
     sinfo_msg_warning("xc=%f yc=%f",piqe[0],piqe[1]); 
@@ -445,7 +445,7 @@ test_strehl_two(void)
 
 
     piqe=cpl_bivector_get_x_data(iqe1);
-    //*star_peak=piqe[5];
+    //  *star_peak=piqe[5];
     xpos1=piqe[0];
     ypos1=piqe[1];
     sinfo_msg_warning("xc1=%f yc1=%f",piqe[0],piqe[1]); 
@@ -471,7 +471,7 @@ test_strehl_two(void)
 
 
     piqe=cpl_bivector_get_x_data(iqe1);
-    //*star_peak=piqe[5];
+    //  *star_peak=piqe[5];
     xpos2=piqe[0];
     ypos2=piqe[1];
     sinfo_msg_warning("xc2=%f yc2=%f",piqe[0],piqe[1]); 
