@@ -112,10 +112,10 @@ static cpl_error_code atmo_disp_load_params(
 //			"ESO TEL PARANG END",
 			"CDELT3"
 	};
-	double airmass_start;
-	double airmass_end;
-	double pres_start,	pres_end;
-	double parang_start, parang_end;
+	double airmass_start=0.;
+	double airmass_end=0.;
+	double pres_start=0.,	pres_end=0.;
+	double parang_start=0., parang_end=0.;
 	cpl_propertylist* plist = cpl_propertylist_load(fits_file, 0);
 	cpl_error_code err = CPL_ERROR_NONE;
 	int sz = 0;
@@ -348,7 +348,7 @@ static void atmo_test_dispersion_cube( const char* fits_file, const char* out_fi
 }
 static void atmo_apply_cube_polynomial_shift(cpl_polynomial* poly, const char* fits_file, const char* out_file)
 {
-	cpl_error_code 	err = CPL_ERROR_NONE;
+
     cpl_imagelist* pCube = 0;
     double lambda0 = 0;
     double Tc = 0;
@@ -363,7 +363,7 @@ static void atmo_apply_cube_polynomial_shift(cpl_polynomial* poly, const char* f
 	double * kernel = sinfo_generate_interpolation_kernel("default");
 
 
-	err = atmo_disp_load_params(fits_file, &centpix, &lambda0, &Tc, &rh, &airmass, &p, &parallactic, &pixelscale, &pixelsz);
+	cpl_error_code err = atmo_disp_load_params(fits_file, &centpix, &lambda0, &Tc, &rh, &airmass, &p, &parallactic, &pixelscale, &pixelsz);
 	cpl_msg_warning(cpl_func, "centpix[%d] lambda0[%f] angle[%f]", centpix, lambda0, parallactic);
 	parallactic = parallactic * PI_NUMB / 180; // convert to radian
     pCube = cpl_imagelist_load(fits_file, CPL_TYPE_FLOAT, 0);
@@ -449,7 +449,7 @@ static void atmo_init_offset_table(cpl_table** big_table, int big_table_size)
 }
 static void atmo_process_fits_data_file(cpl_table** ptable, const char* filename)
 {
-	cpl_error_code err = CPL_ERROR_NONE;
+
 	// open the file
 	const int CUTOFF_PLANES = 80;
 	int centpix 	= 0;
@@ -469,7 +469,7 @@ static void atmo_process_fits_data_file(cpl_table** ptable, const char* filename
 	cpl_imagelist* pCube = 0;
 	// read the airmass from the file
 
-	err = atmo_disp_load_params(filename, &centpix, &lambda0, &Tc, &rh, &airm, &p, &parallactic, &pixelscale, &pixelsz);
+	cpl_error_code err = atmo_disp_load_params(filename, &centpix, &lambda0, &Tc, &rh, &airm, &p, &parallactic, &pixelscale, &pixelsz);
 	if(err != CPL_ERROR_NONE)
 	{
 		cpl_msg_warning(cpl_func, "error [%s]", filename);
@@ -583,7 +583,6 @@ static void atmo_rotate_point(double* x_value, double* y_value, double rot_angle
 static void atmo_prepare_offset_table(const char* cfg_filename, const char* output_filename)
 {
 	FILE * pFile;
-    char fitsfilename [1024];
     cpl_table* tables[1500];
     cpl_table* big_table = 0;
     int next_table = 0;
@@ -598,9 +597,10 @@ static void atmo_prepare_offset_table(const char* cfg_filename, const char* outp
 	}
 	else
 	{
-		double lambda0 = 0;
+		//double lambda0 = 0;
 		int isLambda0 = 0;
 		// prepare table
+		char fitsfilename [1024];
 		while (fgets (fitsfilename , 1024 , pFile))
 		{
 			if(fitsfilename[0] != '#')
@@ -615,7 +615,9 @@ static void atmo_prepare_offset_table(const char* cfg_filename, const char* outp
 				if (isLambda0 == 0)
 				{
 					isLambda0 = 1;
-					lambda0 = atmo_get_general_lambda0(fitsfilename);
+					/* the following value is not used
+					 * lambda0 = atmo_get_general_lambda0(fitsfilename);
+					 */
 				}
 				pptable = &(tables[next_table++]);
 				atmo_process_fits_data_file(pptable, fitsfilename);
@@ -683,19 +685,10 @@ static void atmo_filter_resultset(double value_min, double value_max,
 		const char* fits_file_input,
 		const char* fits_file_output)
 {
-	const char* COLS[] = {
-			COL_NAME_CENTRE_X,
-			COL_NAME_CENTRE_Y,
-			COL_NAME_AIRMASS,
-			COL_NAME_WAVELENGTH,
-			COL_NAME_ANGLE,
-			COL_NAME_OFFSET_X,
-			COL_NAME_OFFSET_Y,
-	};
+
 	cpl_table* ptable = 0;
 	int nrow = 0;
 	cpl_table* ptableresult = 0;
-	static int ncols = sizeof(COLS) / sizeof(COLS[0]);
 	// open the file
 	ptable = cpl_table_load(fits_file_input, 1,0);
 	if (ptable == 0)
@@ -709,6 +702,16 @@ static void atmo_filter_resultset(double value_min, double value_max,
 	{
 		int i;
 		int result_pos = 0;
+	    const char* COLS[] = {
+	            COL_NAME_CENTRE_X,
+	            COL_NAME_CENTRE_Y,
+	            COL_NAME_AIRMASS,
+	            COL_NAME_WAVELENGTH,
+	            COL_NAME_ANGLE,
+	            COL_NAME_OFFSET_X,
+	            COL_NAME_OFFSET_Y,
+	    };
+		static int ncols = sizeof(COLS) / sizeof(COLS[0]);
 		for (i = 0; i < nrow; i++)
 		{
 			int inull = 0;
@@ -763,7 +766,6 @@ static cpl_polynomial* atmo_prepare_polyfit(const char* input_filename)
 	cpl_polynomial  * fit2d = 0;
 	cpl_matrix      * points = 0;
 	cpl_vector      * fitvals = 0;
-	cpl_error_code    err = CPL_ERROR_NONE;
 	cpl_size maxdeg2d = 3;
 	cpl_table* ptable;
 
@@ -792,7 +794,7 @@ static cpl_polynomial* atmo_prepare_polyfit(const char* input_filename)
 				cpl_msg_warning(cpl_func, "invalid element #%d", i);
 			}
 		}
-		err = cpl_error_get_code();
+		cpl_error_code err = cpl_error_get_code();
 		if (err == CPL_ERROR_NONE)
 		{
 			fit2d = cpl_polynomial_new(2);
@@ -860,7 +862,6 @@ static void atmo_prepare_poly_net(cpl_polynomial* poly, const char* filename)
 static void atmo_apply_cube_polynomial_shift_list(cpl_polynomial* poly, const char* list_file)
 {
 	FILE * pFile;
-    char fitsfilename [1024];
     pFile = fopen (list_file , "r");
 
     if (pFile == NULL)
@@ -871,6 +872,7 @@ static void atmo_apply_cube_polynomial_shift_list(cpl_polynomial* poly, const ch
  	else
  	{
  		// prepare table
+ 	   char fitsfilename [1024];
  		while (fgets (fitsfilename , 1024 , pFile))
  		{
  			if(fitsfilename[0] != '#')
